#Section 1: Create clean R workspace ----
rm(list=ls())
graphics.off()
gc(FALSE)
cat("\014")
Sys.setenv(LANG = "en")
options(max.print = 20000)

#Section 2: Open libraries and datasets ----
#Open packages:
Pkgs2Load <- c("ggplot2", "emmeans", "multcomp", "glmmTMB", "DHARMa")

invisible(lapply(Pkgs2Load, library, character.only = TRUE))

#Set the working directory.
setwd([WORKING DIRECTORY])

#Import data files
PH <- read.csv2("Herb_sem_data_harvest.csv")
CC <- read.csv2("Herb_sem_data_insects.csv")

#Merge community and harvest data
PH.nometa <- PH[,c(1,9:11,13:38)]
PH.merge <- merge(CC, PH.nometa, by = "ID")
CC <- PH.merge

#Section 3: Prepare the data ----
cols <- c("Location","Treatment","Cultivar","Field","Year")

#Subsection 3.1: Create variables and remove irrelevant variables
CC$Placement <- ifelse(CC$Row_number == "N/A", "Pixel", ifelse(CC$Row_number == "2" | CC$Row_number == "3", "Center", "Edge"))
CC$Year <- CC$Year2
names(CC)[names(CC)=="Field_number"] <- "Field"

CC$FWwrapper <- CC$`FW wrapper (g)` / 1000
CC$`FW wrapper (g)` <-NULL
CC$FWhead <- (CC$`FW clean head` + CC$`FW dmg head leaves`) / 1000
CC$FWdamhead <- CC$`FW dmg head leaves` / 1000
CC$Yieldloss <- CC$FWdamhead / CC$FWhead
CC$Yieldloss <- round(CC$Yieldloss * 100, digits = 0)

CC$Leaves1 <- CC$`#Leaves1`
CC$`#Leaves1` <- NULL
CC$Leaves2 <- CC$`#Leaves2`
CC$`#Leaves2` <- NULL
CC$Leaves3 <- CC$`#Leaves3`
CC$`#Leaves3` <- NULL
CC$Leaves4 <- CC$`#Leaves4`
CC$`#Leaves4` <- NULL
CC$Leaves5 <- CC$`#Leaves5`
CC$`#Leaves5` <- NULL

#Subsection 3.2: Change level Treatments
CC$Treatment <- factor(CC$Treatment, levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"))
CC$Treatment <- factor(CC$Treatment,
                       levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"),
                       labels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity", "Pixel"))
CC$Location <- factor(CC$Location, levels = c("Droevendaal", "Broekemahoeve"))

#Subsection 3.3: Change field names
CC$Field <- factor(CC$Field,
                   levels = c("1","2","3","5","10","J8_1","J8_3","J8_4","J9_2","J10_1"),
                   labels = c("1","2","3","4", "4","J9"  ,"J9"  ,"J8"  ,"J9" , "J10"))
CC$Field2 <- factor(CC$Field,
                    levels = c("1","2","3","4","J8","J9","J10"),
                    labels = c("Other","Other","Other","Monoculture", "Other","Monoculture","Other"))

#Subsection 3.4: Include Expect cv. with Rivera
CC$Cultivar[CC$Cultivar == "Expect"] <- "Rivera"
CC[cols] <- lapply(CC[cols], factor)

#Subsection 3.5: Remove replacement cabbages
CC$Replacement[is.na(CC$Replacement)] <- 0
CC <- subset(CC[CC$Replacement != 1,])

plantpar <- c("Radius1", "Radius2", "Radius3", "Radius4", "Radius5",
              "Leaves1", "Leaves2", "Leaves3", "Leaves4", "Leaves5",
              "Dmg(1-10)1", "Dmg(1-10)2", "Dmg(1-10)3", "Dmg(1-10)4", "Dmg(1-10)5")
CC[plantpar] <- lapply(CC[plantpar],as.numeric)

#Subsection 3.5.2: Remove cabbages that did not grow a head
CC <- subset(CC[CC$Head == 1,])

#Subsection 3.6: Add herbivores together
CC$Lb1 <- rowSums(CC[,c("Pha1", "Phu1")], na.rm = FALSE)
CC$Lb2 <- rowSums(CC[,c("Pha2", "Phu2")], na.rm = FALSE)
CC$Lb3 <- rowSums(CC[,c("Pha3", "Phu3")], na.rm = FALSE)
CC$Lb4 <- rowSums(CC[,c("Pha4", "Phu4")], na.rm = FALSE)
CC$Lb_early <- ifelse(is.na(CC$Lb1) == TRUE, CC$Lb2, (CC$Lb1 + CC$Lb2)/2)
CC$Lb_late <- (CC$Lb3 + CC$Lb4)/2
CC$LOG_Lb_early <- log(CC$Lb_early + 1)
CC$LOG_Lb_late <- log(CC$Lb_late + 1)

CC$Ch1 <- rowSums(CC[,c("Plx1", "Pr1", "Pb1", "Mb1", "Ag1", "Evergestis forficalis1", "Army_worm1", "Athalia1", "Weevil1")], na.rm = FALSE)
CC$Ch2 <- rowSums(CC[,c("Plx2", "Pr2", "Pb2", "Mb2", "Ag2", "Evergestis forficalis2", "Army_worm2", "Athalia2", "Weevil2")], na.rm = FALSE)
CC$Ch3 <- rowSums(CC[,c("Plx3", "Pr3", "Pb3", "Mb3", "Ag3", "Evergestis forficalis3", "Army_worm3", "Athalia3", "Weevil3")], na.rm = FALSE)
CC$Ch4 <- rowSums(CC[,c("Plx4", "Pr4", "Pb4", "Mb4", "Ag4", "Evergestis forficalis4", "Army_worm4", "Athalia4", "Weevil4")], na.rm = FALSE)
CC$Ch_early <- ifelse(is.na(CC$Ch1) == TRUE, CC$Ch2, (CC$Ch1 + CC$Ch2)/2)
CC$Ch_late <- (CC$Ch3 + CC$Ch4)/2
CC$LOG_Ch_early <- log(CC$Ch_early + 1)
CC$LOG_Ch_late <- log(CC$Ch_late + 1)

CC$Su1 <- rowSums(CC[,c("Bb1", "Mp1", "Mpn1", "Black1", "A_other1", "Wfly1", "Cicada1")], na.rm = TRUE)
CC$Su2 <- rowSums(CC[,c("Bb2", "Mp2", "Mpn2", "Black2", "A_other2", "Wfly2", "Cicada2")], na.rm = TRUE)
CC$Su3 <- rowSums(CC[,c("Bb3", "Mp3", "Mpn3", "Black3", "A_other3", "Wfly3", "Cicada3")], na.rm = TRUE)
CC$Su4 <- rowSums(CC[,c("Bb4", "Mp4", "Mpn4", "Black4", "A_other4", "Wfly4", "Cicada4")], na.rm = TRUE)
CC$Su_early <- ifelse(is.na(CC$Su1) == TRUE, CC$Su2, (CC$Su1 + CC$Su2)/2)
CC$Su_late <- (CC$Su3 + CC$Su4)/2
CC$LOG_Su_early <- log(CC$Su_early + 1)
CC$LOG_Su_late <- log(CC$Su_late + 1)

CC$Thrips_early <- ifelse(is.na(CC$Thrips1) == TRUE, CC$Thrips2, (CC$Thrips1 + CC$Thrips2)/2)
CC$Thrips_late <- (CC$Thrips3 + CC$Thrips4)/2
CC$LOG_Thrips_early <- log(CC$Thrips_early + 1)
CC$LOG_Thrips_late <- log(CC$Thrips_late + 1)

CC$Herb_early <- rowSums(CC[,c("Lb_early", "Ch_early", "Su_early", "Thrips_early")], na.rm = TRUE)
CC$Herb_late <- rowSums(CC[,c("Lb_late", "Ch_late", "Su_late", "Thrips_late")], na.rm = TRUE)
CC$Herb_early <- round(CC$Herb_early, digits = 0)
CC$Herb_late <- round(CC$Herb_late, digits = 0)

CC$Richness1 <- ifelse(CC$Phu1 == 0, 0, 1) +
  ifelse(CC$Pha1 == 0, 0, 1) +
  ifelse(CC$Weevil1 == 0, 0, 1) +
  ifelse(CC$Pr1 == 0, 0, 1) +
  ifelse(CC$Pb1 == 0, 0, 1) +
  ifelse(CC$Plx1 == 0, 0, 1) +
  ifelse(CC$Mb1 == 0, 0, 1) +
  ifelse(CC$Ag1 == 0, 0, 1) +
  ifelse(CC$Army_worm1 == 0, 0, 1) +
  ifelse(CC$Bb1 == 0, 0, 1) +
  ifelse(CC$Mp1 == 0, 0, 1) +
  ifelse(CC$Black1 == 0, 0, 1) +
  ifelse(CC$Mpn1 == 0, 0, 1) +
  ifelse(CC$A_other1 > 0 & CC$Bb1 + CC$Mp1 + CC$Black1 + CC$Mpn1 == 0, 1, 0) +
  ifelse(CC$Cicada1 == 0, 0, 1) +
  ifelse(CC$Thrips1 == 0, 0, 1) +
  ifelse(CC$Wfly1 == 0, 0, 1) +
  ifelse(CC$Athalia1 == 0, 0, 1) +
  ifelse(CC$Miner1 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis1` == 0, 0, 1) +
  ifelse(CC$Shield_bug1 == 0, 0, 1) +
  ifelse(CC$Het_others1 == 0, 0, 1)
CC$Richness2 <- ifelse(CC$Phu2 == 0, 0, 1) +
  ifelse(CC$Pha2 == 0, 0, 1) +
  ifelse(CC$Weevil2 == 0, 0, 1) +
  ifelse(CC$Pr2 == 0, 0, 1) +
  ifelse(CC$Pb2 == 0, 0, 1) +
  ifelse(CC$Plx2 == 0, 0, 1) +
  ifelse(CC$Mb2 == 0, 0, 1) +
  ifelse(CC$Ag2 == 0, 0, 1) +
  ifelse(CC$Army_worm2 == 0, 0, 1) +
  ifelse(CC$Bb2 == 0, 0, 1) +
  ifelse(CC$Mp2 == 0, 0, 1) +
  ifelse(CC$Black2 == 0, 0, 1) +
  ifelse(CC$Mpn2 == 0, 0, 1) +
  ifelse(CC$A_other2 > 0 & CC$Bb2 + CC$Mp2 + CC$Black2 + CC$Mpn2 == 0, 1, 0) +
  ifelse(CC$Cicada2 == 0, 0, 1) +
  ifelse(CC$Thrips2 == 0, 0, 1) +
  ifelse(CC$Wfly2 == 0, 0, 1) +
  ifelse(CC$Athalia2 == 0, 0, 1) +
  ifelse(CC$Miner2 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis2` == 0, 0, 1) +
  ifelse(CC$Shield_bug2 == 0, 0, 1) +
  ifelse(CC$Het_others2 == 0, 0, 1)
CC$Richness3 <- ifelse(CC$Phu3 == 0, 0, 1) +
  ifelse(CC$Pha3 == 0, 0, 1) +
  ifelse(CC$Weevil3 == 0, 0, 1) +
  ifelse(CC$Pr3 == 0, 0, 1) +
  ifelse(CC$Pb3 == 0, 0, 1) +
  ifelse(CC$Plx3 == 0, 0, 1) +
  ifelse(CC$Mb3 == 0, 0, 1) +
  ifelse(CC$Ag3 == 0, 0, 1) +
  ifelse(CC$Army_worm3 == 0, 0, 1) +
  ifelse(CC$Bb3 == 0, 0, 1) +
  ifelse(CC$Mp3 == 0, 0, 1) +
  ifelse(CC$Black3 == 0, 0, 1) +
  ifelse(CC$Mpn3 == 0, 0, 1) +
  ifelse(CC$A_other3 > 0 & CC$Bb3 + CC$Mp3 + CC$Black3 + CC$Mpn3 == 0, 1, 0) +
  ifelse(CC$Cicada3 == 0, 0, 1) +
  ifelse(CC$Thrips3 == 0, 0, 1) +
  ifelse(CC$Wfly3 == 0, 0, 1) +
  ifelse(CC$Athalia3 == 0, 0, 1) +
  ifelse(CC$Miner3 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis3` == 0, 0, 1) +
  ifelse(CC$Shield_bug3 == 0, 0, 1) +
  ifelse(CC$Het_others3 == 0, 0, 1)
CC$Richness4 <- ifelse(CC$Phu4 == 0, 0, 1) +
  ifelse(CC$Pha4 == 0, 0, 1) +
  ifelse(CC$Weevil4 == 0, 0, 1) +
  ifelse(CC$Pr4 == 0, 0, 1) +
  ifelse(CC$Pb4 == 0, 0, 1) +
  ifelse(CC$Plx4 == 0, 0, 1) +
  ifelse(CC$Mb4 == 0, 0, 1) +
  ifelse(CC$Ag4 == 0, 0, 1) +
  ifelse(CC$Army_worm4 == 0, 0, 1) +
  ifelse(CC$Bb4 == 0, 0, 1) +
  ifelse(CC$Mp4 == 0, 0, 1) +
  ifelse(CC$Black4 == 0, 0, 1) +
  ifelse(CC$Mpn4 == 0, 0, 1) +
  ifelse(CC$A_other4 > 0 & CC$Bb4 + CC$Mp4 + CC$Black4 + CC$Mpn4 == 0, 1, 0) +
  ifelse(CC$Cicada4 == 0, 0, 1) +
  ifelse(CC$Thrips4 == 0, 0, 1) +
  ifelse(CC$Wfly4 == 0, 0, 1) +
  ifelse(CC$Athalia4 == 0, 0, 1) +
  ifelse(CC$Miner4 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis4` == 0, 0, 1) +
  ifelse(CC$Shield_bug4 == 0, 0, 1) +
  ifelse(CC$Het_others4 == 0, 0, 1)
CC$Richness_early <- ifelse(is.na(CC$Richness1) == TRUE, CC$Richness2, (CC$Richness1 + CC$Richness2)/2)
CC$Richness_late <- (CC$Richness3 + CC$Richness4)/2
CC$Richness_early <- round(CC$Richness_early, digits = 0)
CC$Richness_late <- round(CC$Richness_late, digits = 0)

CC$LOG_FWhead <- log(CC$FWhead + 1)
CC$LOG_FWwrapper <- log(CC$FWwrapper + 1)

#Subsection 3.7: Remove N/A's 
CC <- CC[!is.na(CC$Radius3),]
CC <- CC[!is.na(CC$LOG_FWwrapper),]

#Subsection 3.8: Split CD vs Rivera from Treatment effects.
CCT <- CC[CC$Cultivar != "Christmas drumhead",]
CCT[cols] <- lapply(CCT[cols],factor)

CCC <- CC[CC$Treatment == "Strip_cultivar",]
CCC[cols] <- lapply(CCC[cols],factor)

CCC$Cultivar <- factor(CCC$Cultivar, levels = c("Rivera", "Christmas drumhead"))


#Subsection 3.9: Make subsets
CCT.nopix <- subset(CCT[CCT$Treatment != "Pixel",])
CCT.nopix[cols] <- lapply(CCT.nopix[cols],factor)


#Section 4: Early herbivore abundance ----
#Subsection 4.1: Both locations --> All treatments
TMEA1 <- glmmTMB(log(Herb_early + 1) ~ 1 + Treatment + Placement + 
                   Year + Location + Year*Location +
                   (1|Field/Line_number),
                family = gaussian(),
                dispformula = ~ 1,
                ziformula =~ 0,
                data = CCT.nopix, na.action = na.fail)
HSD.TMEA1 <- emmeans(ref_grid(TMEA1, regrid = "response"), pairwise ~ Treatment)
CLD.TMEA1 <- cld(HSD.TMEA1$emmeans, Letters = letters)
CLD.TMEA1$.group <- gsub(" ", "", CLD.TMEA1$.group)


#Section 5: Late herbivore abundance ----
#Subsection 5.1: Both locations --> All treatments
TMLA1 <- glmmTMB(log(Herb_late + 1) ~ 1 + Treatment + Placement + 
                   Year + Location + Year*Location +
                   (1|Field/Line_number),
                 family = gaussian(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.nopix, na.action = na.fail)
HSD.TMLA1 <- emmeans(ref_grid(TMLA1, regrid = "response"), pairwise ~ Treatment)
CLD.TMLA1 <- cld(HSD.TMLA1$emmeans, Letters = letters)
CLD.TMLA1$.group <- gsub(" ", "", CLD.TMLA1$.group)


#Section 6: Early herbivore richness ----
#Subsection 6.1: Droevendaal --> All treatments
TMER1 <- glmmTMB(Richness_early ~ 1 + Treatment + Placement + 
                   Year + Location + Year*Location +
                   (1|Field/Line_number),
                 family = gaussian(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.nopix, na.action = na.fail)
HSD.TMER1 <- emmeans(ref_grid(TMER1, regrid = "response"), pairwise ~ Treatment)
CLD.TMER1 <- cld(HSD.TMER1$emmeans, Letters = letters)
CLD.TMER1$.group <- gsub(" ", "", CLD.TMER1$.group)

#Section 7: Late herbivore richness ----
#Subsection 7.1: Droevendaal --> All treatments
TMLR1 <- glmmTMB(Richness_late ~ 1 + Treatment + Placement + 
                   Year + Location + Year*Location +
                   (1|Field/Line_number),
                 family = gaussian(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.nopix, na.action = na.fail)
HSD.TMLR1 <- emmeans(ref_grid(TMLR1, regrid = "response"), pairwise ~ Treatment)
CLD.TMLR1 <- cld(HSD.TMLR1$emmeans, Letters = letters)
CLD.TMLR1$.group <- gsub(" ", "", CLD.TMLR1$.group)


#Section 8: Figures ----
# Subsection 8.1: Preparations
Droef.colors <- c("#895F39", "#B6D663", "#27a6b0", "#213F9A", "#9671B2") #, "#B32E5F")


#Section 8.2: Early herbivore abundance ----
pdf(file = "Abundance early - Both locations.pdf", width = 5, height = 7)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Herb_early)) +
  #geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMEA1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 3, linewidth = 2) + 
  #ylim(0,3.5) +
  geom_text(data = CLD.TMEA1, aes(label = .group, x = Treatment, y = upper.CL + 1), cex = 10) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 20), 
        axis.text.x = element_text(size = 19, color = "black"), axis.title.x = element_text(margin = margin(t = 20)),  
        axis.text.y = element_text(size = 19, color = "black"), axis.title.y = element_text(margin = margin(r = 20)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Early herbivore abundance") 
dev.off()


#Section 8.3: Late herbivore abundance ----
pdf(file = "Abundance late - Both locations.pdf", width = 5, height = 7)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Herb_late)) +
  #geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMLA1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 3, linewidth = 2) + 
  #ylim(0,3.5) +
  geom_text(data = CLD.TMLA1, aes(label = .group, x = Treatment, y = upper.CL + 1), cex = 10) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 20), 
        axis.text.x = element_text(size = 19, color = "black"), axis.title.x = element_text(margin = margin(t = 20)),  
        axis.text.y = element_text(size = 19, color = "black"), axis.title.y = element_text(margin = margin(r = 20)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Late herbivore abundance") 
dev.off()


#Section 8.4: Early herbivore richness ----
pdf(file = "Richness early - Both locations.pdf", width = 5, height = 7)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Richness_early)) +
  #geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMER1, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 3, linewidth = 2) + 
  #ylim(0,3.5) +
  geom_text(data = CLD.TMER1, aes(label = .group, x = Treatment, y = upper.CL + 0.1), cex = 10) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 20), 
        axis.text.x = element_text(size = 19, color = "black"), axis.title.x = element_text(margin = margin(t = 20)),  
        axis.text.y = element_text(size = 19, color = "black"), axis.title.y = element_text(margin = margin(r = 20)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Early herbivore richness") 
dev.off()


#Section 8.5: Late herbivore richness ----
pdf(file = "Richness late - Both locations.pdf", width = 5, height = 7)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Richness_late)) +
  #geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMLR1, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 3, linewidth = 2) + 
  #ylim(0,3.5) +
  geom_text(data = CLD.TMLR1, aes(label = .group, x = Treatment, y = upper.CL + 0.1), cex = 10) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 20), 
        axis.text.x = element_text(size = 19, color = "black"), axis.title.x = element_text(margin = margin(t = 20)),  
        axis.text.y = element_text(size = 19, color = "black"), axis.title.y = element_text(margin = margin(r = 20)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Late herbivore richness") 
dev.off()