#Section 1: Create clean R workspace ----
rm(list=ls())
graphics.off()
gc(FALSE)
cat("\014")
Sys.setenv(LANG = "en")
options(max.print = 2000)

#Section 2: Open libraries and datasets ----
#Open packages:
Pkgs2Load <- c("ggplot2", "emmeans", "multcomp", "glmmTMB", "DHARMa")

invisible(lapply(Pkgs2Load, library, character.only = TRUE))

#Set the working directory.
setwd([WORKING DIRECTORY])

#Import data files
PH <- read.csv2("Herb_sem_data_harvest.csv")

#Section 3: Prepare the data----
cols <- c("Location","Treatment","Cultivar","Field","Year")

#Subsection 3.1: Create variables and remove irrelevant variables
PH$Placement <- ifelse(PH$Row_number == "N/A", "Pixel", ifelse(PH$Row_number == "2" | PH$Row_number == "3", "Center", "Edge"))
PH$Year <- format(as.Date(PH$`Harvest date`, format="%d/%m/%Y"),"%Y")

PH$FWhead <- (PH$`FW clean head` + PH$`FW dmg head leaves`) / 1000
PH$FWdamhead <- PH$`FW dmg head leaves` / 1000
PH$Yieldloss <- PH$FWdamhead / PH$FWhead
PH$Yieldloss <- round(PH$Yieldloss * 100, digits = 0)


#Subsection 3.2: Change level Treatments
PH$Treatment <- factor(PH$Treatment, levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"))
PH$Treatment <- factor(PH$Treatment,
                       levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"),
                       labels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity", "Pixel"))
PH$Location <- factor(PH$Location, levels = c("Droevendaal", "Broekemahoeve"))


#Subsection 3.3: Change field names
PH$Field <- factor(PH$Field,
                   levels = c("1","2","3","5","10","J8_1","J8_3","J8_4","J9_2","J10_1"),
                   labels = c("1","2","3","4", "4","J9"  ,"J9"  ,"J8"  ,"J9" , "J10"))


#Subsection 3.4: Include Expect cv. with Rivera
PH$Cultivar[PH$Cultivar == "Expect"] <- "Rivera"
PH[cols] <- lapply(PH[cols], factor)


#Subsection 3.5: Remove N/A's 
PH <- subset(PH, !is.na(FWhead))


#Subsection 3.6: Remove replacement cabbages
PH$Replacement[is.na(PH$Replacement)] <- 0
PH <- subset(PH[PH$Replacement != 1,])


#Subsection 3.7: Remove cabbages that did not form a head
PH$Head[is.na(PH$Head)] <- 0
PH <- subset(PH[PH$Head != 0,])


#Subsection 3.8: Split CD vs Rivera from Treatment effects.
PHT <- PH[PH$Cultivar != "Christmas drumhead",]
PHT[cols] <- lapply(PHT[cols],factor)

PHT.nopix <- subset(PHT[PHT$Treatment != "Pixel",])
PHT.nopix[cols] <- lapply(PHT.nopix[cols],factor)


#Subsection 3.9: Reduce X_coordinates to ranges
PHT.nopix$X <- cut(PHT.nopix$X_coordinate, seq(9,58,4))


#Subsection 3.10: Make subsets
PHT.ref <- subset(PHT.nopix[PHT.nopix$Field == "4" | PHT.nopix$Field == "J9" | (PHT.nopix$Field == "J8" & (PHT.nopix$Treatment == "Strip" | PHT.nopix$Treatment == "Monoculture")),])
PHT.strip <- subset(PHT.nopix[(PHT.nopix$Treatment == "Strip" | PHT.nopix$Treatment == "Strip_cultivar" | PHT.nopix$Treatment == "Strip_additive") & PHT.nopix$Field != "4" & PHT.nopix$Field != "J9",])

PHT.droef <- subset(PHT.nopix[PHT.nopix$Location == "Droevendaal",])
PHT.droef.nopix <- subset(PHT.droef[PHT.droef$Treatment != "Pixel",])
PHT.droef.no4 <- subset(PHT.droef.nopix[PHT.droef.nopix$Field != "4",])
PHT.droef.ref <- subset(PHT.droef[PHT.droef$Field == "4",])

PHT.broek <- subset(PHT.nopix[PHT.nopix$Location == "Broekemahoeve",])
PHT.broek.noref <- subset(PHT.broek[PHT.broek$Field != "J9" & PHT.broek$Treatment != "Monoculture",])
PHT.broek.ref <- subset(PHT.broek[PHT.broek$Field == "J9" | PHT.broek$Treatment == "Monoculture" | (PHT.broek$Treatment == "Strip" & PHT.broek$Year == "2019" & PHT.broek$Field == "J8"),])


#Section 4: Fresh weight head ----
#Subsection 4.1: Droevendaal --> Monoculture field
TMY1 <- glmmTMB(FWhead ~ 1 + Treatment + Placement +  
                  Year +
                  (1|Line_number),
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.droef.ref, na.action = na.fail)
HSD.TMY1 <- emmeans(ref_grid(TMY1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMY1 <- cld(HSD.TMY1$emmeans, Letters = c("A","B","C"))
CLD.TMY1$.group <- gsub(" ", "", CLD.TMY1$.group)

#Subsection 4.2: Droevendaal --> All strip treatments
TMY2 <- glmmTMB(FWhead ~ 1 + Treatment + Placement +  
                  Year + Field +
                  (1|Line_number) + 
                  Treatment*(Year) +
                  Field*Year,
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.droef.no4, na.action = na.fail)
HSD.TMY2 <- emmeans(ref_grid(TMY2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMY2 <- cld(HSD.TMY2$emmeans, Letters = letters)
CLD.TMY2$.group <- gsub(" ", "", CLD.TMY2$.group)

#Subsection 4.4: Broekemahoeve --> Monoculture
TMY3 <- glmmTMB(FWhead ~ 1 + Treatment + Placement +  
                  Year +
                  (1|Line_number),
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.broek.ref, na.action = na.fail)
HSD.TMY3 <- emmeans(ref_grid(TMY3, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMY3 <- cld(HSD.TMY3$emmeans, Letters = c("A","B","C"))
CLD.TMY3$.group <- gsub(" ", "", CLD.TMY3$.group)

#Subsection 4.4: Broekemahoeve --> All strip treatments
TMY4 <- glmmTMB(FWhead ~ 1 + Treatment + Placement +  
                  Year + Field +
                  (1|Line_number) + 
                  Treatment*(Year),
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.broek.noref, na.action = na.fail)
HSD.TMY4 <- emmeans(ref_grid(TMY4, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMY4 <- cld(HSD.TMY4$emmeans, Letters = letters)
CLD.TMY4$.group <- gsub(" ", "", CLD.TMY4$.group)


#Section 5: Fresh weight head full model ----
TMY5 <- glmmTMB(FWhead ~ 1 + Treatment + Placement + 
                  Year + Location + Year*Location +
                  (1|Field/Line_number),
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.nopix, na.action = na.fail)
HSD.TMY5 <- emmeans(ref_grid(TMY5, regrid = "response"), pairwise ~ Treatment)
CLD.TMY5 <- cld(HSD.TMY5$emmeans, Letters = letters)
CLD.TMY5$.group <- gsub(" ", "", CLD.TMY5$.group)

TMY6 <- glmmTMB(FWhead ~ 1 + Treatment + Placement + 
                  Year + Location + Year*Location +
                  (1|Field/Line_number),
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.nopix[PHT.nopix$Treatment != "Strip_diversity",], na.action = na.fail)
HSD.TMY6 <- emmeans(ref_grid(TMY6, regrid = "response"), pairwise ~ Treatment)
CLD.TMY6 <- cld(HSD.TMY6$emmeans, Letters = letters)
CLD.TMY6$.group <- gsub(" ", "", CLD.TMY6$.group)


#Section 6: Proportion damaged head weight ----
#Subsection 6.1: Droevendaal --> All treatments
TMM1 <- glmmTMB(Yieldloss ~ 1 + Treatment + Placement +   
                  Year + Field +
                  Treatment*Year,
                family = nbinom2(),
                dispformula = ~ 1,
                ziformula =~ 1,
                data = PHT.droef.nopix, na.action = na.fail)
HSD.TMM1 <- emmeans(ref_grid(TMM1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMM1 <- cld(HSD.TMM1$emmeans, Letters = letters)
CLD.TMM1$.group <- gsub(" ", "", CLD.TMM1$.group)


#Subsection 6.2: Broekemahoeve --> All treatments
TMM2 <- glmmTMB(Yieldloss ~ 1 + Treatment + Placement +   
                  Year + Field + 
                  Treatment*(Year),
                family = nbinom2(),
                dispformula = ~ 1,
                ziformula =~ 1,
                data = PHT.broek, na.action = na.fail)
HSD.TMM2 <- emmeans(ref_grid(TMM2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMM2 <- cld(HSD.TMM2$emmeans, Letters = letters)
CLD.TMM2$.group <- gsub(" ", "", CLD.TMM2$.group)

#Subsection 6.3: All data ----
TMM3 <- glmmTMB(Yieldloss ~ 1 + Treatment + Placement + 
                  Year + Location + Year*Location +
                  (1|Field/Line_number),
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.nopix, na.action = na.fail)
HSD.TMM3 <- emmeans(ref_grid(TMM3, regrid = "response"), pairwise ~ Treatment)
CLD.TMM3 <- cld(HSD.TMM3$emmeans, Letters = letters)
CLD.TMM3$.group <- gsub(" ", "", CLD.TMM3$.group)

TMM4 <- glmmTMB(Yieldloss ~ 1 + Treatment + Placement + 
                  Year + Location + Year*Location +
                  (1|Field/Line_number),
                family = gaussian,
                dispformula = ~ 1,
                ziformula =~ 0,
                data = PHT.nopix[PHT.nopix$Treatment != "Strip_diversity",], na.action = na.fail)
HSD.TMM4 <- emmeans(ref_grid(TMM4, regrid = "response"), pairwise ~ Treatment)
CLD.TMM4 <- cld(HSD.TMM4$emmeans, Letters = letters)
CLD.TMM4$.group <- gsub(" ", "", CLD.TMM4$.group)


#Section 6: Figures ----
# Subsection 6.1: Preparations
Droef.colors <- c("#895F39", "#B6D663", "#27a6b0", "#213F9A", "#9671B2") #, "#B32E5F")
Broek.colors <- c("#895F39", "#B6D663", "#27a6b0", "#213F9A")

#Subsection 6.2: Fresh weight head
#Subsection 6.2.1: Droevendaal
PHT.droef.nopix$Field2 <- ifelse(PHT.droef.nopix$Field == "4", "Monoculture", "Other")

png(filename = "FW head - Droevendaal.png", width = 2838, height = 3500, res = 400)
ggplot(data = PHT.droef.nopix, aes(x = Treatment, y = FWhead)) +
  geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Field2)) +
  geom_pointrange(data = CLD.TMY1, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  geom_pointrange(data = CLD.TMY2, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1) + ylim(0,2.6) +
  geom_text(data = CLD.TMY1, aes(label = .group, x = Treatment, y = 2.4)) +
  geom_text(data = CLD.TMY2, aes(label = .group, x = Treatment, y = 2.6)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(title = "Droevendaal", x = "Cropping design", y = "Fresh weight cabbage head (kg)") 
dev.off()

#Subsection 6.2.2: Broekemahoeve
PHT.broek$Field2 <- ifelse(PHT.broek$Field == "J9" | PHT.broek$Treatment == "Monoculture", "Monoculture", "Other")

png(filename = "FW head - Broekemahoeve.png", width = 2322, height = 3500, res = 400)
ggplot(data = PHT.broek, aes(x = Treatment, y = FWhead)) +
  geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Field2)) +
  geom_pointrange(data = CLD.TMY3, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  geom_pointrange(data = CLD.TMY4, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1) + ylim(0,3.5) +
  geom_text(data = CLD.TMY3, aes(label = .group, x = Treatment, y = 3.2)) +
  geom_text(data = CLD.TMY4, aes(label = .group, x = Treatment, y = 3.5)) +
  scale_color_manual(values = Broek.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(title = "Broekemahoeve", x = "Cropping design", y = "Fresh weight cabbage head (kg)") 
dev.off()

#Subsection 6.2.3: All data
pdf(file = "FW head - Both locations.pdf", width = 5, height = 7)
ggplot(data = PHT.nopix, aes(x = Treatment, y = FWhead)) +
  #geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMY5, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 3, linewidth = 2) + 
  #ylim(0,3.5) +
  geom_text(data = CLD.TMY5, aes(label = .group, x = Treatment, y = upper.CL + 0.1), cex = 10) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 20), 
        axis.text.x = element_text(size = 19, color = "black"), axis.title.x = element_text(margin = margin(t = 20)),  
        axis.text.y = element_text(size = 19, color = "black"), axis.title.y = element_text(margin = margin(r = 20)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Fresh weight cabbage head (kg)") 
dev.off()


#Subsection 6.3: Proportion marketable weight
#Subsection 6.3.1: Droevendaal
png(filename = "Proportion damaged head weight - Droevendaal.png", width = 2838, height = 3500, res = 400)
ggplot(data = PHT.droef.nopix, aes(x = Treatment, y = Yieldloss)) +
  geom_jitter(aes(x = Treatment, y = Yieldloss, color = Treatment)) +
  geom_pointrange(data = CLD.TMM1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1) + ylim(-1,55) +
  geom_text(data = CLD.TMM1, aes(label = .group, x = Treatment, y = 55)) +
  scale_color_manual(values = Droef.colors) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 13, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(title = "Droevendaal", x = "Cropping design", y = "Proportion damaged head weight (%)") 
dev.off()

#Subsection 6.3.2: Broekemahoeve
png(filename = "Proportion damaged head weight - Broekemahoeve.png", width = 2322, height = 3500, res = 400)
ggplot(data = PHT.broek, aes(x = Treatment, y = Yieldloss)) +
  geom_jitter(aes(x = Treatment, y = Yieldloss, color = Treatment)) +
  geom_pointrange(data = CLD.TMM2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1) + ylim(-1,55) +
  geom_text(data = CLD.TMM2, aes(label = .group, x = Treatment, y = 55)) +
  scale_color_manual(values = Broek.colors) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 13, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(title = "Broekemahoeve", x = "Cropping design", y = "Proportion damaged head weight (%)") 
dev.off()

#Subsection 6.3.3: All data
pdf(file = "Damage - Both locations.pdf", width = 5, height = 7)
ggplot(data = PHT.nopix, aes(x = Treatment, y = Yieldloss)) +
  #geom_jitter(aes(x = Treatment, y = FWhead, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMM3, aes(x = Treatment, y = emmean, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 3, linewidth = 2) + 
  #ylim(0,3.5) +
  #geom_text(data = CLD.TMM3, aes(label = .group, x = Treatment, y = upper.CL + 1), cex = 10) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 20), 
        axis.text.x = element_text(size = 19, color = "black"), axis.title.x = element_text(margin = margin(t = 20)),  
        axis.text.y = element_text(size = 19, color = "black"), axis.title.y = element_text(margin = margin(r = 20)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Proportion damaged head weight (%)") 
dev.off()
