#Section 1: Create clean R workspace ----
rm(list=ls())
graphics.off()
gc(FALSE)
cat("\014")
Sys.setenv(LANG = "en")
options(max.print = 20000)

#Section 2: Open libraries and datasets ----
#Open packages:
Pkgs2Load <- c("ggplot2", "emmeans", "multcomp", "glmmTMB", "DHARMa")

invisible(lapply(Pkgs2Load, library, character.only = TRUE))

#Set the working directory.
setwd([WORKING DIRECTORY])

#Import data files
PH <- read.csv2("Herb_sem_data_harvest.csv")
CC <- read.csv2("Herb_sem_data_insects.csv")

#Merge community and harvest data
PH.nometa <- PH[,c(1,9:11,13:38)]
PH.merge <- merge(CC, PH.nometa, by = "ID")
CC <- PH.merge
#Section 3: Prepare the data----
cols <- c("Location","Treatment","Cultivar","Field","Year")

#Subsection 3.1: Create variables and remove irrelevant variables
CC$Placement <- ifelse(CC$Row_number == "N/A", "Pixel", ifelse(CC$Row_number == "2" | CC$Row_number == "3", "Center", "Edge"))
CC$Year <- CC$Year2
names(CC)[names(CC)=="Field_number"] <- "Field"

#Subsection 3.2: Change level Treatments
CC$Treatment <- factor(CC$Treatment, levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"))
CC$Treatment <- factor(CC$Treatment,
                       levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"),
                       labels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity", "Pixel"))
CC$Location <- factor(CC$Location, levels = c("Droevendaal", "Broekemahoeve"))

#Subsection 3.3: Change field names
CC$Field <- factor(CC$Field,
                   levels = c("1","2","3","5","10","J8_1","J8_3","J8_4","J9_2","J10_1"),
                   labels = c("1","2","3","4", "4","J9"  ,"J9"  ,"J8"  ,"J9" , "J10"))

#Subsection 3.4: Include Expect cv. with Rivera
CC$Cultivar[CC$Cultivar == "Expect"] <- "Rivera"
CC[cols] <- lapply(CC[cols], factor)

#Subsection 3.5.1: Remove replacement cabbages
CC$Replacement[is.na(CC$Replacement)] <- 0
CC <- subset(CC[CC$Replacement != 1,])

#Subsection 3.5.2: Remove cabbages that did not grow a head
CC <- subset(CC[CC$Head == 1,])

#Subsection 3.6: Add herbivores together
CC$Fb1 <- rowSums(CC[,c("Pha1", "Phu1")], na.rm = FALSE)
CC$Fb2 <- rowSums(CC[,c("Pha2", "Phu2")], na.rm = FALSE)
CC$Fb3 <- rowSums(CC[,c("Pha3", "Phu3")], na.rm = FALSE)
CC$Fb4 <- rowSums(CC[,c("Pha4", "Phu4")], na.rm = FALSE)
CC$Fb_early <- round(ifelse(is.na(CC$Fb1) == TRUE, CC$Fb2, (CC$Fb1 + CC$Fb2)/2), digits = 0)
CC$Fb_late <- round((CC$Fb3 + CC$Fb4)/2, digits = 0)
CC$LOG_Fb_early <- log(CC$Fb_early + 1)
CC$LOG_Fb_late <- log(CC$Fb_late + 1)

CC$Ch1 <- rowSums(CC[,c("Plx1", "Pr1", "Pb1", "Mb1", "Ag1", "Evergestis forficalis1", "Army_worm1", "Athalia1", "Weevil1")], na.rm = FALSE)
CC$Ch2 <- rowSums(CC[,c("Plx2", "Pr2", "Pb2", "Mb2", "Ag2", "Evergestis forficalis2", "Army_worm2", "Athalia2", "Weevil2")], na.rm = FALSE)
CC$Ch3 <- rowSums(CC[,c("Plx3", "Pr3", "Pb3", "Mb3", "Ag3", "Evergestis forficalis3", "Army_worm3", "Athalia3", "Weevil3")], na.rm = FALSE)
CC$Ch4 <- rowSums(CC[,c("Plx4", "Pr4", "Pb4", "Mb4", "Ag4", "Evergestis forficalis4", "Army_worm4", "Athalia4", "Weevil4")], na.rm = FALSE)
CC$Ch_early <- round(ifelse(is.na(CC$Ch1) == TRUE, CC$Ch2, (CC$Ch1 + CC$Ch2)/2), digits = 0)
CC$Ch_late <- round((CC$Ch3 + CC$Ch4)/2, digits = 0)
CC$LOG_Ch_early <- log(CC$Ch_early + 1)
CC$LOG_Ch_late <- log(CC$Ch_late + 1)

CC$Su1 <- rowSums(CC[,c("Bb1", "Mp1", "Mpn1", "Black1", "A_other1", "Wfly1", "Cicada1")], na.rm = TRUE)
CC$Su2 <- rowSums(CC[,c("Bb2", "Mp2", "Mpn2", "Black2", "A_other2", "Wfly2", "Cicada2")], na.rm = TRUE)
CC$Su3 <- rowSums(CC[,c("Bb3", "Mp3", "Mpn3", "Black3", "A_other3", "Wfly3", "Cicada3")], na.rm = TRUE)
CC$Su4 <- rowSums(CC[,c("Bb4", "Mp4", "Mpn4", "Black4", "A_other4", "Wfly4", "Cicada4")], na.rm = TRUE)
CC$Su_early <- round(ifelse(is.na(CC$Su1) == TRUE, CC$Su2, (CC$Su1 + CC$Su2)/2), digits = 0)
CC$Su_late <- round((CC$Su3 + CC$Su4)/2, digits = 0)
CC$LOG_Su_early <- log(CC$Su_early + 1)
CC$LOG_Su_late <- log(CC$Su_late + 1)

CC$Th_early <- round(ifelse(is.na(CC$Thrips1) == TRUE, CC$Thrips2, (CC$Thrips1 + CC$Thrips2)/2), digits = 0)
CC$Th_late <- round((CC$Thrips3 + CC$Thrips4)/2, digits = 0)
CC$LOG_Th_early <- log(CC$Th_early + 1)
CC$LOG_Th_late <- log(CC$Th_late + 1)

#Subsection 3.7: Remove N/A's 
CC <- CC[!is.na(CC$Radius3),]

#Subsection 3.8: Split CD vs Rivera from Treatment effects.
CCT <- CC[CC$Cultivar != "Christmas drumhead",]
CCT[cols] <- lapply(CCT[cols],factor)

CCC <- CC[CC$Treatment == "Strip_cultivar",]
CCC[cols] <- lapply(CCC[cols],factor)

CCC$Cultivar <- factor(CCC$Cultivar, levels = c("Rivera", "Christmas drumhead"))

#Subsection 3.9: Make subsets
CCT.nopix <- subset(CCT[CCT$Treatment != "Pixel",])
CCT.nopix[cols] <- lapply(CCT.nopix[cols],factor)

CCT.ref <- subset(CCT.nopix[CCT.nopix$Field == "4" | CCT.nopix$Field == "J9" | (CCT.nopix$Field == "J8" & (CCT.nopix$Treatment == "Strip" | CCT.nopix$Treatment == "Monoculture")),])
CCT.strip <- subset(CCT.nopix[(CCT.nopix$Treatment == "Strip" | CCT.nopix$Treatment == "Strip_cultivar" | CCT.nopix$Treatment == "Strip_additive") & CCT.nopix$Field != "4" & CCT.nopix$Field != "J9",])

CCT.droef <- subset(CCT.nopix[CCT.nopix$Location == "Droevendaal",])
CCT.droef.nopix <- subset(CCT.droef[CCT.droef$Treatment != "Pixel",])
CCT.droef.no4 <- subset(CCT.droef.nopix[CCT.droef.nopix$Field != "4",])
CCT.droef.ref <- subset(CCT.droef[CCT.droef$Field == "4",])

CCT.broek <- subset(CCT.nopix[CCT.nopix$Location == "Broekemahoeve",])
CCT.broek.noref <- subset(CCT.broek[CCT.broek$Field != "J9" & CCT.broek$Treatment != "Monoculture",])
CCT.broek.ref <- subset(CCT.broek[CCT.broek$Field == "J9" | CCT.broek$Treatment == "Monoculture" | (CCT.broek$Treatment == "Strip" & CCT.broek$Year == "2019" & CCT.broek$Field == "J8"),])

CCC.droef <- subset(CCC[CCC$Location == "Droevendaal",])
CCC.broek <- subset(CCC[CCC$Location == "Broekemahoeve",])
#Section 4: Early chewer abundance ----
#Subsection 4.1: Droevendaal --> All treatments
TMEC1 <- glmmTMB(Ch_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMEC1 <- emmeans(ref_grid(TMEC1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMEC1 <- cld(HSD.TMEC1$emmeans, Letters = letters)
CLD.TMEC1$.group <- gsub(" ", "", CLD.TMEC1$.group)


#Subsection 4.2: Broekemahoeve --> All treatments
TMEC2 <- glmmTMB(Ch_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMEC2 <- emmeans(ref_grid(TMEC2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMEC2 <- cld(HSD.TMEC2$emmeans, Letters = c("A","B","C"))
CLD.TMEC2$.group <- gsub(" ", "", CLD.TMEC2$.group)


#Subsection 4.3: Droevendaal --> Cultivars
CMEC1 <- glmmTMB(Ch_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMEC1 <- emmeans(ref_grid(CMEC1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMEC1 <- cld(HSD.CMEC1$emmeans, Letters = letters)
CLD.CMEC1$.group <- gsub(" ", "", CLD.CMEC1$.group)


#Subsection 4.4: Broekemahoeve --> Cultivars
CMEC2 <- glmmTMB(Ch_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMEC2 <- emmeans(ref_grid(CMEC2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMEC2 <- cld(HSD.CMEC2$emmeans, Letters = c("A","B","C"))
CLD.CMEC2$.group <- gsub(" ", "", CLD.CMEC2$.group)

#Section 5: Early sucker abundance ----
#Subsection 5.1: Droevendaal --> All treatments
TMES1 <- glmmTMB(Su_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMES1 <- emmeans(ref_grid(TMES1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMES1 <- cld(HSD.TMES1$emmeans, Letters = letters)
CLD.TMES1$.group <- gsub(" ", "", CLD.TMES1$.group)


#Subsection 5.2: Broekemahoeve --> All treatments
TMES2 <- glmmTMB(Su_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMES2 <- emmeans(ref_grid(TMES2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMES2 <- cld(HSD.TMES2$emmeans, Letters = c("A","B","C"))
CLD.TMES2$.group <- gsub(" ", "", CLD.TMES2$.group)


#Subsection 5.3: Droevendaal --> Cultivars
CMES1 <- glmmTMB(Su_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMES1 <- emmeans(ref_grid(CMES1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMES1 <- cld(HSD.CMES1$emmeans, Letters = letters)
CLD.CMES1$.group <- gsub(" ", "", CLD.CMES1$.group)


#Subsection 5.4: Broekemahoeve --> Cultivars
CMES2 <- glmmTMB(Su_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMES2 <- emmeans(ref_grid(CMES2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMES2 <- cld(HSD.CMES2$emmeans, Letters = c("A","B","C"))
CLD.CMES2$.group <- gsub(" ", "", CLD.CMES2$.group)

#Section 6: Early thrips abundance ----
#Subsection 6.1: Droevendaal --> All treatments
TMET1 <- glmmTMB(Th_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMET1 <- emmeans(ref_grid(TMET1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMET1 <- cld(HSD.TMET1$emmeans, Letters = letters)
CLD.TMET1$.group <- gsub(" ", "", CLD.TMET1$.group)


#Subsection 6.2: Broekemahoeve --> All treatments
TMET2 <- glmmTMB(Th_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMET2 <- emmeans(ref_grid(TMET2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMET2 <- cld(HSD.TMET2$emmeans, Letters = c("A","B","C"))
CLD.TMET2$.group <- gsub(" ", "", CLD.TMET2$.group)


#Subsection 6.3: Droevendaal --> Cultivars
CMET1 <- glmmTMB(Th_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMET1 <- emmeans(ref_grid(CMET1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMET1 <- cld(HSD.CMET1$emmeans, Letters = letters)
CLD.CMET1$.group <- gsub(" ", "", CLD.CMET1$.group)


#Subsection 6.4: Broekemahoeve --> Cultivars
CMET2 <- glmmTMB(Th_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMET2 <- emmeans(ref_grid(CMET2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMET2 <- cld(HSD.CMET2$emmeans, Letters = c("A","B","C"))
CLD.CMET2$.group <- gsub(" ", "", CLD.CMET2$.group)

#Section 7: Early flea beetle abundance ----
#Subsection 7.1: Droevendaal --> All treatments
TMEF1 <- glmmTMB(Fb_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMEF1 <- emmeans(ref_grid(TMEF1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMEF1 <- cld(HSD.TMEF1$emmeans, Letters = letters)
CLD.TMEF1$.group <- gsub(" ", "", CLD.TMEF1$.group)


#Subsection 7.2: Broekemahoeve --> All treatments
TMEF2 <- glmmTMB(Fb_early ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMEF2 <- emmeans(ref_grid(TMEF2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMEF2 <- cld(HSD.TMEF2$emmeans, Letters = c("A","B","C","D"))
CLD.TMEF2$.group <- gsub(" ", "", CLD.TMEF2$.group)


#Subsection 7.3: Droevendaal --> Cultivars
CMEF1 <- glmmTMB(Fb_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMEF1 <- emmeans(ref_grid(CMEF1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMEF1 <- cld(HSD.CMEF1$emmeans, Letters = letters)
CLD.CMEF1$.group <- gsub(" ", "", CLD.CMEF1$.group)


#Subsection 7.4: Broekemahoeve --> Cultivars
CMEF2 <- glmmTMB(Fb_early ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMEF2 <- emmeans(ref_grid(CMEF2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMEF2 <- cld(HSD.CMEF2$emmeans, Letters = c("A","B","C"))
CLD.CMEF2$.group <- gsub(" ", "", CLD.CMEF2$.group)

#Section 8: Late chewer abundance ----
#Subsection 8.1: Droevendaal --> All treatments
TMLC1 <- glmmTMB(Ch_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMLC1 <- emmeans(ref_grid(TMLC1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLC1 <- cld(HSD.TMLC1$emmeans, Letters = letters)
CLD.TMLC1$.group <- gsub(" ", "", CLD.TMLC1$.group)


#Subsection 8.2: Broekemahoeve --> All treatments
TMLC2 <- glmmTMB(Ch_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMLC2 <- emmeans(ref_grid(TMLC2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLC2 <- cld(HSD.TMLC2$emmeans, Letters = c("A","B","C"))
CLD.TMLC2$.group <- gsub(" ", "", CLD.TMLC2$.group)


#Subsection 8.3: Droevendaal --> Cultivars
CMLC1 <- glmmTMB(Ch_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMLC1 <- emmeans(ref_grid(CMLC1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLC1 <- cld(HSD.CMLC1$emmeans, Letters = letters)
CLD.CMLC1$.group <- gsub(" ", "", CLD.CMLC1$.group)


#Subsection 8.4: Broekemahoeve --> Cultivars
CMLC2 <- glmmTMB(Ch_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMLC2 <- emmeans(ref_grid(CMLC2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLC2 <- cld(HSD.CMLC2$emmeans, Letters = c("A","B","C"))
CLD.CMLC2$.group <- gsub(" ", "", CLD.CMLC2$.group)

#Section 9: Late sucker abundance ----
#Subsection 9.1: Droevendaal --> All treatments
TMLS1 <- glmmTMB(Su_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMLS1 <- emmeans(ref_grid(TMLS1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLS1 <- cld(HSD.TMLS1$emmeans, Letters = letters)
CLD.TMLS1$.group <- gsub(" ", "", CLD.TMLS1$.group)


#Subsection 9.2: Broekemahoeve --> All treatments
TMLS2 <- glmmTMB(Su_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMLS2 <- emmeans(ref_grid(TMLS2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLS2 <- cld(HSD.TMLS2$emmeans, Letters = c("A","B","C"))
CLD.TMLS2$.group <- gsub(" ", "", CLD.TMLS2$.group)


#Subsection 9.3: Droevendaal --> Cultivars
CMLS1 <- glmmTMB(Su_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMLS1 <- emmeans(ref_grid(CMLS1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLS1 <- cld(HSD.CMLS1$emmeans, Letters = letters)
CLD.CMLS1$.group <- gsub(" ", "", CLD.CMLS1$.group)


#Subsection 9.4: Broekemahoeve --> Cultivars
CMLS2 <- glmmTMB(Su_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMLS2 <- emmeans(ref_grid(CMLS2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLS2 <- cld(HSD.CMLS2$emmeans, Letters = c("A","B","C"))
CLD.CMLS2$.group <- gsub(" ", "", CLD.CMLS2$.group)

#Section 10: Late thrips abundance ----
#Subsection 10.1: Droevendaal --> All treatments
TMLT1 <- glmmTMB(Th_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMLT1 <- emmeans(ref_grid(TMLT1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLT1 <- cld(HSD.TMLT1$emmeans, Letters = letters)
CLD.TMLT1$.group <- gsub(" ", "", CLD.TMLT1$.group)


#Subsection 10.2: Broekemahoeve --> All treatments
TMLT2 <- glmmTMB(Th_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMLT2 <- emmeans(ref_grid(TMLT2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLT2 <- cld(HSD.TMLT2$emmeans, Letters = c("A","B","C"))
CLD.TMLT2$.group <- gsub(" ", "", CLD.TMLT2$.group)


#Subsection 10.3: Droevendaal --> Cultivars
CMLT1 <- glmmTMB(Th_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMLT1 <- emmeans(ref_grid(CMLT1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLT1 <- cld(HSD.CMLT1$emmeans, Letters = letters)
CLD.CMLT1$.group <- gsub(" ", "", CLD.CMLT1$.group)


#Subsection 10.4: Broekemahoeve --> Cultivars
CMLT2 <- glmmTMB(Th_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMLT2 <- emmeans(ref_grid(CMLT2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLT2 <- cld(HSD.CMLT2$emmeans, Letters = c("A","B","C"))
CLD.CMLT2$.group <- gsub(" ", "", CLD.CMLT2$.group)

#Section 11: Late flea beetle abundance ----
#Subsection 11.1: Droevendaal --> All treatments
TMLF1 <- glmmTMB(Fb_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.droef.nopix, na.action = na.fail)
HSD.TMLF1 <- emmeans(ref_grid(TMLF1, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLF1 <- cld(HSD.TMLF1$emmeans, Letters = letters)
CLD.TMLF1$.group <- gsub(" ", "", CLD.TMLF1$.group)


#Subsection 11.2: Broekemahoeve --> All treatments
TMLF2 <- glmmTMB(Fb_late ~ 1 + Treatment + Placement +   
                   Year + Field +
                   Treatment*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCT.broek, na.action = na.fail)
HSD.TMLF2 <- emmeans(ref_grid(TMLF2, regrid = "response"), pairwise ~ Treatment | Year)
CLD.TMLF2 <- cld(HSD.TMLF2$emmeans, Letters = c("A","B","C"))
CLD.TMLF2$.group <- gsub(" ", "", CLD.TMLF2$.group)


#Subsection 11.3: Droevendaal --> Cultivars
CMLF1 <- glmmTMB(Fb_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.droef, na.action = na.fail)
HSD.CMLF1 <- emmeans(ref_grid(CMLF1, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLF1 <- cld(HSD.CMLF1$emmeans, Letters = letters)
CLD.CMLF1$.group <- gsub(" ", "", CLD.CMLF1$.group)


#Subsection 11.4: Broekemahoeve --> Cultivars
CMLF2 <- glmmTMB(Fb_late ~ 1 + Cultivar +    
                   Year + Field +
                   Cultivar*(Year),
                 family = nbinom2(),
                 dispformula = ~ 1,
                 ziformula =~ 0,
                 data = CCC.broek, na.action = na.fail)
HSD.CMLF2 <- emmeans(ref_grid(CMLF2, regrid = "response"), pairwise ~ Cultivar | Year)
CLD.CMLF2 <- cld(HSD.CMLF2$emmeans, Letters = c("A","B","C"))
CLD.CMLF2$.group <- gsub(" ", "", CLD.CMLF2$.group)

#Section 12: Figures ----
# Subsection 12.1: Preparations
Droef.colors <- c("#895F39", "#B6D663", "#27a6b0", "#213F9A", "#9671B2") #, "#B32E5F")
Cultivar.colors <- c("#FF9997", "#619CFF")


#Section 12.2: Early chewer abundance ----
png(filename = "Early chewer abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Ch_early)) +
  geom_jitter(aes(x = Treatment, y = Ch_early, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMEC1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMEC2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-5, 101) +
  geom_text(data = CLD.TMEC1, aes(label = .group, x = Treatment, y = 90)) +
  geom_text(data = CLD.TMEC2, aes(label = .group, x = Treatment, y = 100)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Early chewer abundance") 
dev.off()

png(filename = "Early chewer abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Ch_early)) +
  geom_jitter(aes(x = Cultivar, y = Ch_early, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMEC1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMEC2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-5, 101) +
  geom_text(data = CLD.CMEC1, aes(label = .group, x = Cultivar, y = 90)) +
  geom_text(data = CLD.CMEC2, aes(label = .group, x = Cultivar, y = 100)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Early chewer abundance") 
dev.off()

#Section 12.3: Early sucker abundance ----
png(filename = "Early sucker abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Su_early)) +
  geom_jitter(aes(x = Treatment, y = Su_early, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMES1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMES2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-5, 50) +
  geom_text(data = CLD.TMES1, aes(label = .group, x = Treatment, y = 45)) +
  geom_text(data = CLD.TMES2, aes(label = .group, x = Treatment, y = 50)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Early sucker abundance") 
dev.off()

png(filename = "Early sucker abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Su_early)) +
  geom_jitter(aes(x = Cultivar, y = Su_early, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMES1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMES2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-5, 50) +
  geom_text(data = CLD.CMES1, aes(label = .group, x = Cultivar, y = 45)) +
  geom_text(data = CLD.CMES2, aes(label = .group, x = Cultivar, y = 50)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Early sucker abundance") 
dev.off()

#Section 12.4: Early thrips abundance ----
png(filename = "Early thrips abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Th_early)) +
  geom_jitter(aes(x = Treatment, y = Th_early, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMET1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMET2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 7) +
  geom_text(data = CLD.TMET1, aes(label = .group, x = Treatment, y = 6.3)) +
  geom_text(data = CLD.TMET2, aes(label = .group, x = Treatment, y = 7)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Early thrips abundance") 
dev.off()

png(filename = "Early thrips abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Th_early)) +
  geom_jitter(aes(x = Cultivar, y = Th_early, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMET1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMET2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 7) +
  geom_text(data = CLD.CMET1, aes(label = .group, x = Cultivar, y = 6.3)) +
  geom_text(data = CLD.CMET2, aes(label = .group, x = Cultivar, y = 7)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Early thrips abundance") 
dev.off()

#Section 12.5: Early flea beetle abundance ----
png(filename = "Early flea beetle abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Fb_early)) +
  geom_jitter(aes(x = Treatment, y = Fb_early, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMEF1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMEF2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 15) +
  geom_text(data = CLD.TMEF1, aes(label = .group, x = Treatment, y = 13.5)) +
  geom_text(data = CLD.TMEF2, aes(label = .group, x = Treatment, y = 15)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Early flea beetle abundance") 
dev.off()

png(filename = "Early flea beetle abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Fb_early)) +
  geom_jitter(aes(x = Cultivar, y = Fb_early, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMEF1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMEF2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 15) +
  geom_text(data = CLD.CMEF1, aes(label = .group, x = Cultivar, y = 13.5)) +
  geom_text(data = CLD.CMEF2, aes(label = .group, x = Cultivar, y = 15)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Early flea beetle abundance") 
dev.off()

#Section 12.6: Late chewer abundance ----
png(filename = "Late chewer abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Ch_late)) +
  geom_jitter(aes(x = Treatment, y = Ch_late, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMLC1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMLC2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 15) +
  geom_text(data = CLD.TMLC1, aes(label = .group, x = Treatment, y = 13.5)) +
  geom_text(data = CLD.TMLC2, aes(label = .group, x = Treatment, y = 15)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Late chewer abundance") 
dev.off()

png(filename = "Late chewer abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Ch_late)) +
  geom_jitter(aes(x = Cultivar, y = Ch_late, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMLC1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMLC2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 15) +
  geom_text(data = CLD.CMLC1, aes(label = .group, x = Cultivar, y = 13.5)) +
  geom_text(data = CLD.CMLC2, aes(label = .group, x = Cultivar, y = 15)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Late chewer abundance") 
dev.off()

#Section 12.7: Late sucker abundance ----
png(filename = "Late sucker abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Su_late)) +
  geom_jitter(aes(x = Treatment, y = Su_late, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMLS1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMLS2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-5, 90) +
  geom_text(data = CLD.TMLS1, aes(label = .group, x = Treatment, y = 81)) +
  geom_text(data = CLD.TMLS2, aes(label = .group, x = Treatment, y = 90)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Late sucker abundance") 
dev.off()

png(filename = "Late sucker abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Su_late)) +
  geom_jitter(aes(x = Cultivar, y = Su_late, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMLS1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMLS2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-15, 150) +
  geom_text(data = CLD.CMLS1, aes(label = .group, x = Cultivar, y = 135)) +
  geom_text(data = CLD.CMLS2, aes(label = .group, x = Cultivar, y = 150)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Late sucker abundance") 
dev.off()

#Section 12.8: Late thrips abundance ----
png(filename = "Late thrips abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Th_late)) +
  geom_jitter(aes(x = Treatment, y = Th_late, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMLT1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMLT2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 250) +
  geom_text(data = CLD.TMLT1, aes(label = .group, x = Treatment, y = 225)) +
  geom_text(data = CLD.TMLT2, aes(label = .group, x = Treatment, y = 250)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Late thrips abundance") 
dev.off()

png(filename = "Late thrips abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Th_late)) +
  geom_jitter(aes(x = Cultivar, y = Th_late, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMLT1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMLT2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 250) +
  geom_text(data = CLD.CMLT1, aes(label = .group, x = Cultivar, y = 225)) +
  geom_text(data = CLD.CMLT2, aes(label = .group, x = Cultivar, y = 250)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Late thrips abundance") 
dev.off()

#Section 12.9: Late flea beetle abundance ----
png(filename = "Late flea beetle abundance - Treatments.png", width = 3550, height = 3500, res = 400)
ggplot(data = CCT.nopix, aes(x = Treatment, y = Fb_late)) +
  geom_jitter(aes(x = Treatment, y = Fb_late, color = Treatment,  shape = Location)) +
  geom_pointrange(data = CLD.TMLF1, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.TMLF2, aes(x = Treatment, y = response, ymin = lower.CL, ymax = upper.CL, color = Treatment), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 35) +
  geom_text(data = CLD.TMLF1, aes(label = .group, x = Treatment, y = 31.5)) +
  geom_text(data = CLD.TMLF2, aes(label = .group, x = Treatment, y = 35)) +
  scale_color_manual(values = Droef.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cropping design", y = "Late flea beetle abundance") 
dev.off()

png(filename = "Late flea beetle abundance - Cultivars.png", width = 1610, height = 3500, res = 400)
ggplot(data = CCC, aes(x = Cultivar, y = Fb_late)) +
  geom_jitter(aes(x = Cultivar, y = Fb_late, color = Cultivar,  shape = Location)) +
  geom_pointrange(data = CLD.CMLF1, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 0, size = 0.75) +
  geom_pointrange(data = CLD.CMLF2, aes(x = Cultivar, y = response, ymin = lower.CL, ymax = upper.CL, color = Cultivar), 
                  shape = 15, size = 0.75) +
  facet_wrap(~Year, nrow = 3, ncol = 1, scales = "free_y") + ylim(-1, 35) +
  geom_text(data = CLD.CMLF1, aes(label = .group, x = Cultivar, y = 31.5)) +
  geom_text(data = CLD.CMLF2, aes(label = .group, x = Cultivar, y = 35)) +
  scale_color_manual(values = Cultivar.colors) +
  scale_shape_manual(values = c(2,17)) +
  theme_minimal() + guides(color = FALSE, shape = FALSE) +
  theme(title = element_text(size = 14), axis.title = element_text(size = 18), strip.text = element_text(size = 14),
        axis.text.x = element_text(size = 14, color = "black"), axis.title.x = element_text(margin = margin(t = 15)),  
        axis.text.y = element_text(size = 14, color = "black"), axis.title.y = element_text(margin = margin(r = 15)), 
        panel.grid.major.x = element_blank()) +
  labs(x = "Cultivar", y = "Late flea beetle abundance") 
dev.off()
