#Section 1: Create clean R workspace ----
rm(list=ls())
graphics.off()
gc(FALSE)
cat("\014")
Sys.setenv(LANG = "en")
options(max.print = 2000)

#Section 2: Open libraries and datasets ----
#Open packages:
Pkgs2Load <- c("ggplot2", "ggm", "lavaan", "piecewiseSEM", 
               "nlme", "lme4", "car", "vegan", "DHARMa", "MASS", "gridExtra")

invisible(lapply(Pkgs2Load, library, character.only = TRUE))

#Set the working directory.
setwd([WORKING DIRECTORY])

#Import data files
PH <- read.csv2("Herb_sem_data_harvest.csv")
CC <- read.csv2("Herb_sem_data_insects.csv")

#Merge community and harvest data
PH.nometa <- PH[,c(1,9:11,13:38)]
PH.merge <- merge(CC, PH.nometa, by = "ID")
CC <- PH.merge

#Section 3: Prepare the data ----
cols <- c("Location","Treatment","Cultivar","Field","Year")

#Subsection 3.1: Create variables and remove irrelevant variables
CC$Placement <- ifelse(CC$Row_number == "N/A", "Pixel", ifelse(CC$Row_number == "2" | CC$Row_number == "3", "Center", "Edge"))
CC$Year <- CC$Year2
names(CC)[names(CC)=="Field_number"] <- "Field"

CC$FWwrapper <- CC$`FW wrapper (g)` / 1000
CC$`FW wrapper (g)` <-NULL
CC$FWhead <- (CC$`FW clean head` + CC$`FW dmg head leaves`) / 1000
CC$FWdamhead <- CC$`FW dmg head leaves` / 1000
CC$Yieldloss <- CC$FWdamhead / CC$FWhead
CC$Yieldloss <- round(CC$Yieldloss * 100, digits = 0)

CC$Leaves1 <- CC$`#Leaves1`
CC$`#Leaves1` <- NULL
CC$Leaves2 <- CC$`#Leaves2`
CC$`#Leaves2` <- NULL
CC$Leaves3 <- CC$`#Leaves3`
CC$`#Leaves3` <- NULL
CC$Leaves4 <- CC$`#Leaves4`
CC$`#Leaves4` <- NULL
CC$Leaves5 <- CC$`#Leaves5`
CC$`#Leaves5` <- NULL

#Subsection 3.2: Change level Treatments
CC$Treatment <- factor(CC$Treatment, levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"))
CC$Treatment <- factor(CC$Treatment,
                       levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"),
                       labels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity", "Pixel"))
CC$Location <- factor(CC$Location, levels = c("Droevendaal", "Broekemahoeve"))

#Subsection 3.3: Change field names
CC$Field <- factor(CC$Field,
                   levels = c("1","2","3","5","10","J8_1","J8_3","J8_4","J9_2","J10_1"),
                   labels = c("1","2","3","4", "4","J9"  ,"J9"  ,"J8"  ,"J9" , "J10"))

#Subsection 3.4: Include Expect cv. with Rivera
CC$Cultivar[CC$Cultivar == "Expect"] <- "Rivera"
CC[cols] <- lapply(CC[cols], factor)

#Subsection 3.5: Remove replacement cabbages
CC$Replacement[is.na(CC$Replacement)] <- 0
CC <- subset(CC[CC$Replacement != 1,])

plantpar <- c("Radius1", "Radius2", "Radius3", "Radius4", "Radius5",
              "Leaves1", "Leaves2", "Leaves3", "Leaves4", "Leaves5",
              "Dmg(1-10)1", "Dmg(1-10)2", "Dmg(1-10)3", "Dmg(1-10)4", "Dmg(1-10)5")
CC[plantpar] <- lapply(CC[plantpar],as.numeric)

#Subsection 3.5.2: Remove cabbages that did not grow a head
CC <- subset(CC[CC$Head == 1,])

#Subsection 3.6: Add herbivores together
CC$Lb1 <- rowSums(CC[,c("Pha1", "Phu1")], na.rm = FALSE)
CC$Lb2 <- rowSums(CC[,c("Pha2", "Phu2")], na.rm = FALSE)
CC$Lb3 <- rowSums(CC[,c("Pha3", "Phu3")], na.rm = FALSE)
CC$Lb4 <- rowSums(CC[,c("Pha4", "Phu4")], na.rm = FALSE)
CC$Lb_early <- ifelse(is.na(CC$Lb1) == TRUE, CC$Lb2, (CC$Lb1 + CC$Lb2)/2)
CC$Lb_late <- (CC$Lb3 + CC$Lb4)/2
CC$LOG_Lb_early <- log(CC$Lb_early + 1)
CC$LOG_Lb_late <- log(CC$Lb_late + 1)

CC$Ch1 <- rowSums(CC[,c("Plx1", "Pr1", "Pb1", "Mb1", "Ag1", "Evergestis forficalis1", "Army_worm1", "Athalia1", "Weevil1")], na.rm = FALSE)
CC$Ch2 <- rowSums(CC[,c("Plx2", "Pr2", "Pb2", "Mb2", "Ag2", "Evergestis forficalis2", "Army_worm2", "Athalia2", "Weevil2")], na.rm = FALSE)
CC$Ch3 <- rowSums(CC[,c("Plx3", "Pr3", "Pb3", "Mb3", "Ag3", "Evergestis forficalis3", "Army_worm3", "Athalia3", "Weevil3")], na.rm = FALSE)
CC$Ch4 <- rowSums(CC[,c("Plx4", "Pr4", "Pb4", "Mb4", "Ag4", "Evergestis forficalis4", "Army_worm4", "Athalia4", "Weevil4")], na.rm = FALSE)
CC$Ch_early <- ifelse(is.na(CC$Ch1) == TRUE, CC$Ch2, (CC$Ch1 + CC$Ch2)/2)
CC$Ch_late <- (CC$Ch3 + CC$Ch4)/2
CC$LOG_Ch_early <- log(CC$Ch_early + 1)
CC$LOG_Ch_late <- log(CC$Ch_late + 1)

CC$Su1 <- rowSums(CC[,c("Bb1", "Mp1", "Mpn1", "Black1", "A_other1", "Wfly1", "Cicada1")], na.rm = TRUE)
CC$Su2 <- rowSums(CC[,c("Bb2", "Mp2", "Mpn2", "Black2", "A_other2", "Wfly2", "Cicada2")], na.rm = TRUE)
CC$Su3 <- rowSums(CC[,c("Bb3", "Mp3", "Mpn3", "Black3", "A_other3", "Wfly3", "Cicada3")], na.rm = TRUE)
CC$Su4 <- rowSums(CC[,c("Bb4", "Mp4", "Mpn4", "Black4", "A_other4", "Wfly4", "Cicada4")], na.rm = TRUE)
CC$Su_early <- ifelse(is.na(CC$Su1) == TRUE, CC$Su2, (CC$Su1 + CC$Su2)/2)
CC$Su_late <- (CC$Su3 + CC$Su4)/2
CC$LOG_Su_early <- log(CC$Su_early + 1)
CC$LOG_Su_late <- log(CC$Su_late + 1)

CC$Thrips_early <- ifelse(is.na(CC$Thrips1) == TRUE, CC$Thrips2, (CC$Thrips1 + CC$Thrips2)/2)
CC$Thrips_late <- (CC$Thrips3 + CC$Thrips4)/2
CC$LOG_Thrips_early <- log(CC$Thrips_early + 1)
CC$LOG_Thrips_late <- log(CC$Thrips_late + 1)

CC$Herb_early <- rowSums(CC[,c("Lb_early", "Ch_early", "Su_early", "Thrips_early")], na.rm = TRUE)
CC$Herb_late <- rowSums(CC[,c("Lb_late", "Ch_late", "Su_late", "Thrips_late")], na.rm = TRUE)
CC$LOG_Herb_early <- log(CC$Herb_early + 1)
CC$LOG_Herb_late <- log(CC$Herb_late + 1)

CC$Richness1 <- ifelse(CC$Phu1 == 0, 0, 1) +
  ifelse(CC$Pha1 == 0, 0, 1) +
  ifelse(CC$Weevil1 == 0, 0, 1) +
  ifelse(CC$Pr1 == 0, 0, 1) +
  ifelse(CC$Pb1 == 0, 0, 1) +
  ifelse(CC$Plx1 == 0, 0, 1) +
  ifelse(CC$Mb1 == 0, 0, 1) +
  ifelse(CC$Ag1 == 0, 0, 1) +
  ifelse(CC$Army_worm1 == 0, 0, 1) +
  ifelse(CC$Bb1 == 0, 0, 1) +
  ifelse(CC$Mp1 == 0, 0, 1) +
  ifelse(CC$Black1 == 0, 0, 1) +
  ifelse(CC$Mpn1 == 0, 0, 1) +
  ifelse(CC$A_other1 > 0 & CC$Bb1 + CC$Mp1 + CC$Black1 + CC$Mpn1 == 0, 1, 0) +
  ifelse(CC$Cicada1 == 0, 0, 1) +
  ifelse(CC$Thrips1 == 0, 0, 1) +
  ifelse(CC$Wfly1 == 0, 0, 1) +
  ifelse(CC$Athalia1 == 0, 0, 1) +
  ifelse(CC$Miner1 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis1` == 0, 0, 1) +
  ifelse(CC$Shield_bug1 == 0, 0, 1) +
  ifelse(CC$Het_others1 == 0, 0, 1)
CC$Richness2 <- ifelse(CC$Phu2 == 0, 0, 1) +
  ifelse(CC$Pha2 == 0, 0, 1) +
  ifelse(CC$Weevil2 == 0, 0, 1) +
  ifelse(CC$Pr2 == 0, 0, 1) +
  ifelse(CC$Pb2 == 0, 0, 1) +
  ifelse(CC$Plx2 == 0, 0, 1) +
  ifelse(CC$Mb2 == 0, 0, 1) +
  ifelse(CC$Ag2 == 0, 0, 1) +
  ifelse(CC$Army_worm2 == 0, 0, 1) +
  ifelse(CC$Bb2 == 0, 0, 1) +
  ifelse(CC$Mp2 == 0, 0, 1) +
  ifelse(CC$Black2 == 0, 0, 1) +
  ifelse(CC$Mpn2 == 0, 0, 1) +
  ifelse(CC$A_other2 > 0 & CC$Bb2 + CC$Mp2 + CC$Black2 + CC$Mpn2 == 0, 1, 0) +
  ifelse(CC$Cicada2 == 0, 0, 1) +
  ifelse(CC$Thrips2 == 0, 0, 1) +
  ifelse(CC$Wfly2 == 0, 0, 1) +
  ifelse(CC$Athalia2 == 0, 0, 1) +
  ifelse(CC$Miner2 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis2` == 0, 0, 1) +
  ifelse(CC$Shield_bug2 == 0, 0, 1) +
  ifelse(CC$Het_others2 == 0, 0, 1)
CC$Richness3 <- ifelse(CC$Phu3 == 0, 0, 1) +
  ifelse(CC$Pha3 == 0, 0, 1) +
  ifelse(CC$Weevil3 == 0, 0, 1) +
  ifelse(CC$Pr3 == 0, 0, 1) +
  ifelse(CC$Pb3 == 0, 0, 1) +
  ifelse(CC$Plx3 == 0, 0, 1) +
  ifelse(CC$Mb3 == 0, 0, 1) +
  ifelse(CC$Ag3 == 0, 0, 1) +
  ifelse(CC$Army_worm3 == 0, 0, 1) +
  ifelse(CC$Bb3 == 0, 0, 1) +
  ifelse(CC$Mp3 == 0, 0, 1) +
  ifelse(CC$Black3 == 0, 0, 1) +
  ifelse(CC$Mpn3 == 0, 0, 1) +
  ifelse(CC$A_other3 > 0 & CC$Bb3 + CC$Mp3 + CC$Black3 + CC$Mpn3 == 0, 1, 0) +
  ifelse(CC$Cicada3 == 0, 0, 1) +
  ifelse(CC$Thrips3 == 0, 0, 1) +
  ifelse(CC$Wfly3 == 0, 0, 1) +
  ifelse(CC$Athalia3 == 0, 0, 1) +
  ifelse(CC$Miner3 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis3` == 0, 0, 1) +
  ifelse(CC$Shield_bug3 == 0, 0, 1) +
  ifelse(CC$Het_others3 == 0, 0, 1)
CC$Richness4 <- ifelse(CC$Phu4 == 0, 0, 1) +
  ifelse(CC$Pha4 == 0, 0, 1) +
  ifelse(CC$Weevil4 == 0, 0, 1) +
  ifelse(CC$Pr4 == 0, 0, 1) +
  ifelse(CC$Pb4 == 0, 0, 1) +
  ifelse(CC$Plx4 == 0, 0, 1) +
  ifelse(CC$Mb4 == 0, 0, 1) +
  ifelse(CC$Ag4 == 0, 0, 1) +
  ifelse(CC$Army_worm4 == 0, 0, 1) +
  ifelse(CC$Bb4 == 0, 0, 1) +
  ifelse(CC$Mp4 == 0, 0, 1) +
  ifelse(CC$Black4 == 0, 0, 1) +
  ifelse(CC$Mpn4 == 0, 0, 1) +
  ifelse(CC$A_other4 > 0 & CC$Bb4 + CC$Mp4 + CC$Black4 + CC$Mpn4 == 0, 1, 0) +
  ifelse(CC$Cicada4 == 0, 0, 1) +
  ifelse(CC$Thrips4 == 0, 0, 1) +
  ifelse(CC$Wfly4 == 0, 0, 1) +
  ifelse(CC$Athalia4 == 0, 0, 1) +
  ifelse(CC$Miner4 == 0, 0, 1) +
  ifelse(CC$`Evergestis forficalis4` == 0, 0, 1) +
  ifelse(CC$Shield_bug4 == 0, 0, 1) +
  ifelse(CC$Het_others4 == 0, 0, 1)
CC$Richness_early <- ifelse(is.na(CC$Richness1) == TRUE, CC$Richness2, (CC$Richness1 + CC$Richness2)/2)
CC$Richness_late <- (CC$Richness3 + CC$Richness4)/2

CC$LOG_FWhead <- log(CC$FWhead + 1)
CC$LOG_FWwrapper <- log(CC$FWwrapper + 1)

#Subsection 3.7: Remove N/A's 
CC <- CC[!is.na(CC$Radius3),]
CC <- CC[!is.na(CC$LOG_FWwrapper),]

#Subsection 3.8: Split CD vs Rivera from Treatment effects.
CCT <- CC[CC$Cultivar != "Christmas drumhead",]
CCT[cols] <- lapply(CCT[cols],factor)


#Subsection 3.9: Make subsets
#By treatment
CCT.Ref <- subset(CCT[CCT$Treatment == "Monoculture",])
CCT.Strip <- subset(CCT[CCT$Treatment == "Strip",])
CCT.SC <- subset(CCT[CCT$Treatment == "Strip_cultivar",])
CCT.SA <- subset(CCT[CCT$Treatment == "Strip_additive",])
CCT.SD <- subset(CCT[CCT$Treatment == "Strip_diversity",])
CCT.Pixel <- subset(CCT[CCT$Treatment == "Pixel",])

CCT.nopix <- subset(CCT[CCT$Treatment != "Pixel",])
CCT.nopix[cols] <- lapply(CCT.nopix[cols],factor)

#By year
CCT.19 <- subset(CCT.nopix[CCT.nopix$Year == "2019",])
CCT.20 <- subset(CCT.nopix[CCT.nopix$Year == "2020",])
CCT.21 <- subset(CCT.nopix[CCT.nopix$Year == "2021",])

#By location
CCT.droef <- subset(CCT.nopix[CCT.nopix$Location == "Droevendaal",])
CCT.broek <- subset(CCT.nopix[CCT.nopix$Location == "Broekemahoeve",])

#Section 5: Model with herbivore abundance and richness ----
#Subsection 5.1: Main model (all data) ----
Weightloss_Herb_all <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Location + Year,
     data = CCT),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Location + Year,
         data = CCT),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Location + Year,
     data = CCT),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT
)

summary(Weightloss_Herb_all, conserve = TRUE)

#Subsection 5.2: Model fitting ----
#Subsection 5.2.1: Year
Weightloss_Herb_19 <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Location,
     data = CCT.19),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Location,
     data = CCT.19),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Location,
     data = CCT.19),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location,
     data = CCT.19),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location,
     data = CCT.19),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Location,
         data = CCT.19),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Location,
     data = CCT.19),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.19
)

summary(Weightloss_Herb_19, conserve = TRUE)


#Subsection 5.2.2: Location (incl. Strip_diversity)
Weightloss_Herb_SD <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Year,
     data = CCT.SD),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Year,
     data = CCT.SD),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Year,
     data = CCT.SD),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Year,
     data = CCT.SD),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Year,
     data = CCT.SD),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Year,
         data = CCT.SD),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Year,
     data = CCT.SD),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.SD
)

summary(Weightloss_Herb_SD, conserve = TRUE)


#Subsection 5.2.3: Treatment (except Strip_diversity)
Weightloss_Herb_SD <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.SD),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.SD),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Location + Year,
     data = CCT.SD),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.SD),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.SD),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Location + Year,
         data = CCT.SD),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Location + Year,
     data = CCT.SD),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.SD
)

summary(Weightloss_Herb_SD, conserve = TRUE)

#Subsection 5.3: Run models per treatment ----
#Subsection 5.3.1: Monoculture
Weightloss_Herb_Ref <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.Ref),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.Ref),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Location + Year,
     data = CCT.Ref),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.Ref),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.Ref),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Location + Year,
         data = CCT.Ref),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Location + Year,
     data = CCT.Ref),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.Ref
)

Ref.Summary <- summary(Weightloss_Herb_Ref, conserve = TRUE)


#Subsection 5.3.2: Strip
Weightloss_Herb_Strip <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.Strip),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.Strip),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Location + Year,
     data = CCT.Strip),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.Strip),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.Strip),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Location + Year,
         data = CCT.Strip),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Location + Year,
     data = CCT.Strip),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.Strip
)

Strip.Summary <- summary(Weightloss_Herb_Strip, conserve = TRUE)


#Subsection 5.3.3: Strip_cultivar
Weightloss_Herb_SC <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.SC),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.SC),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Location + Year,
     data = CCT.SC),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.SC),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.SC),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Location + Year,
         data = CCT.SC),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Location + Year,
     data = CCT.SC),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.SC
)

SC.Summary <- summary(Weightloss_Herb_SC, conserve = TRUE)


#Subsection 5.3.4: Strip_additive
Weightloss_Herb_SA <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.SA),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Location + Year,
     data = CCT.SA),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Location + Year,
     data = CCT.SA),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.SA),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Location + Year,
     data = CCT.SA),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Location + Year,
         data = CCT.SA),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Location + Year,
     data = CCT.SA),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.SA
)

SA.Summary <- summary(Weightloss_Herb_SA, conserve = TRUE)


#Subsection 5.3.5: Strip_diversity
Weightloss_Herb_SD <- psem(
  #M1
  lm(LOG_Herb_early ~ Radius2 +  Leaves2 + Year,
     data = CCT.SD),
  
  #M2
  lm(Richness_early ~ Radius2 +  Leaves2 + Year,
     data = CCT.SD),
  
  #M3
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Richness_early + Year,
     data = CCT.SD),
  
  #M4
  lm(LOG_Herb_late ~ Radius2 + Leaves2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Year,
     data = CCT.SD),
  
  #M5
  lm(Richness_late ~ Radius2 + LOG_Herb_early + Richness_early + LOG_FWwrapper + Year,
     data = CCT.SD),
  
  #M6
  glm.nb(Yieldloss ~ LOG_Herb_early + LOG_FWwrapper + LOG_Herb_late + Year,
         data = CCT.SD),
  
  #M7
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Richness_early + LOG_FWwrapper + LOG_Herb_late + Richness_late + Yieldloss + Year,
     data = CCT.SD),
  
  # Correlated structures
  LOG_Herb_early %~~% Richness_early,
  LOG_Herb_late %~~% Richness_late,
  data = CCT.SD
)

SD.Summary <- summary(Weightloss_Herb_SD, conserve = TRUE)


#Section 6: Make figures ----
#Subsection 6.1: Preparations ----
#Colours for treatments
Droef.colors <- c("#895F39", "#B6D663", "#27a6b0", "#213F9A", "#9671B2") #, "#B32E5F")

#Identify summary output that is not useful
Not.Interesting <- c("Year",
                     "Year = 2021",
                     "Year = 2020",
                     "Year = 2019",
                     "Location",
                     "Location = Droevendaal",
                     "Location = Broekemahoeve",
                     "~~Richness_early",
                     "~~Richness_late")

#Remove output that is not useful from treatment summaries
`%notin%` <- Negate(`%in%`)
Paths.Ref <- subset(as.data.frame(Ref.Summary$coefficients), 
                    Predictor %notin% Not.Interesting)
Paths.Strip <- subset(as.data.frame(Strip.Summary$coefficients), 
                      Predictor %notin% Not.Interesting)
Paths.SC <- subset(as.data.frame(SC.Summary$coefficients), 
                   Predictor %notin% Not.Interesting)
Paths.SA <- subset(as.data.frame(SA.Summary$coefficients), 
                   Predictor %notin% Not.Interesting)
Paths.SD <- subset(as.data.frame(SD.Summary$coefficients), 
                   Predictor %notin% Not.Interesting)

#Annotate the subset with the treatment
Paths.Ref$Treatment <- "Monoculture"
Paths.Strip$Treatment <- "Strip"
Paths.SC$Treatment <- "Strip_cultivar"
Paths.SA$Treatment <- "Strip_additive"
Paths.SD$Treatment <- "Strip_diversity"

#Annotate each path with a unique name identifying the path
Paths.Ref$Pathway <- interaction(Paths.Ref$Response, Paths.Ref$Predictor)
Paths.Strip$Pathway <- interaction(Paths.Strip$Response, Paths.Strip$Predictor)
Paths.SC$Pathway <- interaction(Paths.SC$Response, Paths.SC$Predictor)
Paths.SA$Pathway <- interaction(Paths.SA$Response, Paths.SA$Predictor)
Paths.SD$Pathway <- interaction(Paths.SD$Response, Paths.SD$Predictor)

#Bind the results in a larger data frame
combined.results <- rbind(Paths.Ref,
                          Paths.Strip,
                          Paths.SC,
                          Paths.SA,
                          Paths.SD)
combined.results$Pathway <- factor(combined.results$Pathway)
para <- c("Estimate","Std.Error","Std.Estimate")
combined.results[para] <- lapply(combined.results[para], as.numeric)
Paths.Strip[para] <- lapply(Paths.Strip[para], as.numeric)
combined.results$Treatment <- factor(combined.results$Treatment, levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"))

#Create list of all pathways (26 in this model)
Different.Paths <- levels(combined.results$Pathway)


#Subsection 6.2: Figures per parameter ---- 
#Create a list that stores the plots
All_Paths_Plotted <- vector(mode = "list", length = 26)

# Start the loop 
for (i in 1:length(Different.Paths)) {
  
  # Select the path for which results should be plotted
  Path <- subset(combined.results, Pathway == Different.Paths[i])
  
  # Select the path for the control treatment separately (this will be our baseline reference) 
  Strip.Path <- subset(Paths.Strip, Pathway == Different.Paths[i])
  
  
  # Plot with ggplot
  All_Paths_Plotted[[i]] <- 
    ggplot() +
    # The value of the estimate and its 95% interval for each treatment (but not control)
    geom_point(data = Path, aes(x = Treatment, y = Estimate, colour = Treatment)) +
    geom_errorbar(data = Path, aes(x = Treatment,
                                   ymin = Estimate - 1.96*Std.Error, 
                                   ymax = Estimate + 1.96*Std.Error, 
                                   colour = Treatment), 
                  width=.2) +
    # The estimated value of the path for control plants, with 95% interval
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate)) + 
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate - 1.96 * Std.Error), linetype = 2) + 
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate + 1.96 * Std.Error), linetype = 2) + 
    
    # Add some color and a nice layout of the figure
    labs(title = Different.Paths[i],x = "Cropping design", y = "Estimate") +
    scale_colour_manual(values = Droef.colors) +
    guides(colour = "none") +
    
    # This is a custom theme I specified. You can replace this with your own theme or 
    # "theme_bw()" or something similar.
    theme_bw()
  
}

# Define the layout of the plots 
Path_Plots_layout <- rbind(c(1:4),c(5:8),c(9:12),c(13:16),c(17:20),c(21:24),c(25:28)) 
Paths_Plotted <- marrangeGrob(All_Paths_Plotted, nrow = 7, ncol = 4,layout_matrix = Path_Plots_layout)

# Visualize the plots
png(filename = "Model 2 - Differences paths.png", width = 4000, height = 7000, res = 400)
Paths_Plotted
dev.off()


#subsection 6.3: Pathway comparison effect on yield----
All_Effects <- data.frame(matrix(nrow = 8, ncol = 0))

Treatment_Levels <- levels(combined.results$Treatment)

for (i in 1:length(Treatment_Levels)){
  
  # Select the treatment
  Path_Data <- subset(combined.results, Treatment == Treatment_Levels[i])
  
  # Effects of each variable on seed production
  # This is the same calculation you would do in Excel and requires you to 
  # write all of this stuff out for each SEM structure you want to use.
  
  # proportion damaged head weight
  PDW_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Yieldloss"),]$Std.Estimate
  PDW_Indirect <- 0
  PDW_Total <- PDW_Direct + PDW_Indirect
  
  # Late herbivore richness
  LHR_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Richness_late"),]$Std.Estimate
  LHR_Indirect <- 0 
  LHR_Total <- LHR_Direct + LHR_Indirect
  
  # Late herbivore abundance
  LHA_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.LOG_Herb_late"),]$Std.Estimate
  LHA_Indirect <- 
    # Path over proportion damaged head weight
    Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_Herb_late"),]$Std.Estimate * PDW_Total 
  LHA_Total <- LHA_Direct + LHA_Indirect
  
  # Fresh weight wrapper leaves
  FWW_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.LOG_FWwrapper"),]$Std.Estimate
  FWW_Indirect <- 
    # Path over proportion damaged head weight
    Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_FWwrapper"),]$Std.Estimate * PDW_Total +
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.LOG_FWwrapper"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.LOG_FWwrapper"),]$Std.Estimate * LHA_Total 
  FWW_Total <- FWW_Direct + FWW_Indirect
  
  # Early herbivore richness
  EHR_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Richness_early"),]$Std.Estimate
  EHR_Indirect <- 
    # Path over proportion damaged head weight
    0 + 
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.Richness_early"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.Richness_early"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Richness_early"),]$Std.Estimate * FWW_Total
  EHR_Total <- EHR_Direct + EHR_Indirect
  
  # Early herbivore abundance
  EHA_Direct <- 0
  EHA_Indirect <- 
    # Path over proportion damaged head weight
    Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_Herb_early"),]$Std.Estimate * PDW_Total + + 
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.LOG_Herb_early"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.LOG_Herb_early"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves
    0
  EHA_Total <- EHA_Direct + EHA_Indirect
  
  # Leaves T2
  L2_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Leaves2"),]$Std.Estimate
  L2_Indirect <- 
    # Path over proportion damaged head weight
    0 +
    # Path over late herbivore richness
    0 +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.Leaves2"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves 
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Leaves2"),]$Std.Estimate * FWW_Total +
    # Path over early herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_early.Leaves2"),]$Std.Estimate * EHR_Total +
    # Path over early herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_early.Leaves2"),]$Std.Estimate * EHA_Total
  L2_Total <- L2_Direct + L2_Indirect
  
  # Radius T2
  R2_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Radius2"),]$Std.Estimate 
  R2_Indirect <- 
    # Path over proportion damaged head weight
    0 +
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.Radius2"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.Radius2"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves 
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Radius2"),]$Std.Estimate * FWW_Total +
    # Path over early herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_early.Radius2"),]$Std.Estimate * EHR_Total +
    # Path over early herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_early.Radius2"),]$Std.Estimate * EHA_Total
  R2_Total <- R2_Direct + R2_Indirect
  
  # Store all the total effects in a dataframe
  Path_Effects <- as.data.frame(rbind(R2_Total,
                                      L2_Total,
                                      EHA_Total,
                                      EHR_Total,
                                      FWW_Total,
                                      LHA_Total,
                                      LHR_Total,
                                      PDW_Total))
  
  # Annotate the dataframe with the treatment name
  colnames(Path_Effects) <- Treatment_Levels[i]
  
  # Store the result in a bigger dataframe that stores info for each iteration of the for loop
  All_Effects <- cbind(All_Effects,Path_Effects)
  
}

# Wrangle the resulting data frame into the right shape for a heatmap
Stacked_Effects <- data.frame("Treatment" = as.data.frame(stack(All_Effects))$ind,
                              "Path" = c("Early diameter",
                                         "Early number\nof leaves",
                                         "Early herbivore\nabundance",
                                         "Early herbivore\nrichness",
                                         "Fresh weight\nwrapper leaves",
                                         "Late herbivore\nabundance",
                                         "Late herbivore\nrichness",
                                         "Proportion\ndamaged\nhead weight"),
                              "TotalEffect" = as.data.frame(stack(All_Effects))$values)

# Plot a heatmap using ggplot
Stacked_Effects$Treatment2 <- factor(Stacked_Effects$Treatment, 
                                     levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"),
                                     labels = c("Monoculture", "Strip", "Strip\ncultivar", "Strip\nadditive", "Strip\ndiversity"))
Stacked_Effects$Path <- factor(Stacked_Effects$Path, levels = c("Early diameter",
                                                                "Early number\nof leaves",
                                                                "Early herbivore\nabundance",
                                                                "Early herbivore\nrichness",
                                                                "Fresh weight\nwrapper leaves",
                                                                "Late herbivore\nabundance",
                                                                "Late herbivore\nrichness",
                                                                "Proportion\ndamaged\nhead weight"))

pdf(file = "Model 2 - Effect on FW head.pdf", width = 14, height = 17.11111)
ggplot(data = Stacked_Effects, aes(x = Treatment2, y = Path, fill = TotalEffect)) +
  geom_tile() +
  # Add the total effects (rounded to 2 numbers after the decimal point)
  geom_text(aes(label = sprintf("%.2f",TotalEffect)), size = 8) +
  scale_fill_gradient2(name = "Effect on\nfresh weight\nhead",
                       low = "#A51122",
                       mid = "#FFFFFF",
                       high = "#006228",
                       limits = c(-1, 1), 
                       breaks = seq(-1,1,by=0.5)) + 
  theme_bw() +
  theme(axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text = element_text(size = 25),
        legend.title = element_text(size = 20), legend.text = element_text(size = 12)) +
  guides(size = "none")
dev.off()


#subsection 6.4: Pathway comparison effect on proportion damaged head weight----
All_Effects <- data.frame(matrix(nrow = 7, ncol = 0))

Treatment_Levels <- levels(combined.results$Treatment)

for (i in 1:length(Treatment_Levels)){
  
  # Select the treatment
  Path_Data <- subset(combined.results, Treatment == Treatment_Levels[i])

  # Late herbivore richness
  LHR_Direct <- 0
  LHR_Indirect <- 0 
  LHR_Total <- LHR_Direct + LHR_Indirect
  
  # Late herbivore abundance
  LHA_Direct <- Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_Herb_late"),]$Std.Estimate
  LHA_Indirect <- 0
  LHA_Total <- LHA_Direct + LHA_Indirect
  
  # Fresh weight wrapper leaves
  FWW_Direct <- Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_FWwrapper"),]$Std.Estimate
  FWW_Indirect <- 
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.LOG_FWwrapper"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.LOG_FWwrapper"),]$Std.Estimate * LHA_Total 
  FWW_Total <- FWW_Direct + FWW_Indirect
  
  # Early herbivore richness
  EHR_Direct <- 0
  EHR_Indirect <- 
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.Richness_early"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.Richness_early"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Richness_early"),]$Std.Estimate * FWW_Total
  EHR_Total <- EHR_Direct + EHR_Indirect
  
  # Early herbivore abundance
  EHA_Direct <- Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_Herb_early"),]$Std.Estimate
  EHA_Indirect <- 
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.LOG_Herb_early"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.LOG_Herb_early"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves
    0
  EHA_Total <- EHA_Direct + EHA_Indirect
  
  # Leaves T2
  L2_Direct <- 0
  L2_Indirect <-
    # Path over late herbivore richness
    0 +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.Leaves2"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves 
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Leaves2"),]$Std.Estimate * FWW_Total +
    # Path over early herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_early.Leaves2"),]$Std.Estimate * EHR_Total +
    # Path over early herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_early.Leaves2"),]$Std.Estimate * EHA_Total
  L2_Total <- L2_Direct + L2_Indirect
  
  # Radius T2
  R2_Direct <- 0
  R2_Indirect <- 
    # Path over late herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_late.Radius2"),]$Std.Estimate * LHR_Total +
    # Path over late herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_late.Radius2"),]$Std.Estimate * LHA_Total +
    # Path over fresh weight wrapper leaves 
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Radius2"),]$Std.Estimate * FWW_Total +
    # Path over early herbivore richness
    Path_Data[which(Path_Data$Pathway == "Richness_early.Radius2"),]$Std.Estimate * EHR_Total +
    # Path over early herbivore abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Herb_early.Radius2"),]$Std.Estimate * EHA_Total
  R2_Total <- R2_Direct + R2_Indirect
  
  # Store all the total effects in a dataframe
  Path_Effects <- as.data.frame(rbind(R2_Total,
                                      L2_Total,
                                      EHA_Total,
                                      EHR_Total,
                                      FWW_Total,
                                      LHA_Total,
                                      LHR_Total))
  
  # Annotate the dataframe with the treatment name
  colnames(Path_Effects) <- Treatment_Levels[i]
  
  # Store the result in a bigger dataframe that stores info for each iteration of the for loop
  All_Effects <- cbind(All_Effects,Path_Effects)
  
}

# Wrangle the resulting data frame into the right shape for a heatmap
Stacked_Effects <- data.frame("Treatment" = as.data.frame(stack(All_Effects))$ind,
                              "Path" = c("Early diameter",
                                         "Early number\nof leaves",
                                         "Early herbivore\nabundance",
                                         "Early herbivore\nrichness",
                                         "Fresh weight\nwrapper leaves",
                                         "Late herbivore\nabundance",
                                         "Late herbivore\nrichness"),
                              "TotalEffect" = as.data.frame(stack(All_Effects))$values)

# Plot a heatmap using ggplot
Stacked_Effects$Treatment2 <- factor(Stacked_Effects$Treatment, 
                                     levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"),
                                     labels = c("Monoculture", "Strip", "Strip\ncultivar", "Strip\nadditive", "Strip\ndiversity"))
Stacked_Effects$Path <- factor(Stacked_Effects$Path, levels = c("Early diameter",
                                                                "Early number\nof leaves",
                                                                "Early herbivore\nabundance",
                                                                "Early herbivore\nrichness",
                                                                "Fresh weight\nwrapper leaves",
                                                                "Late herbivore\nabundance",
                                                                "Late herbivore\nrichness"))

pdf(file = "Model 2 - Effect on proportion damaged head weight.pdf", width = 14, height = 15.1)
ggplot(data = Stacked_Effects, aes(x = Treatment2, y = Path, fill = TotalEffect)) +
  geom_tile() +
  # Add the total effects (rounded to 2 numbers after the decimal point)
  geom_text(aes(label = sprintf("%.2f",TotalEffect)), size = 8) +
  scale_fill_gradient2(name = "Effect on\ndamaged\nhead weight",
                       low = "#A51122",
                       mid = "#FFFFFF",
                       high = "#006228",
                       limits = c(-1, 1), 
                       breaks = seq(-1,1,by=0.5)) + 
  theme_bw() +
  theme(axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text = element_text(size = 25),
        legend.title = element_text(size = 20), legend.text = element_text(size = 12)) +
  guides(size = "none")
dev.off()
