#Section 1: Create clean R workspace ----
rm(list=ls())
graphics.off()
gc(FALSE)
cat("\014")
Sys.setenv(LANG = "en")
options(max.print = 2000)

#Section 2: Open libraries and datasets ----
#Open packages:
Pkgs2Load <- c("ggplot2", "ggm", "lavaan", "piecewiseSEM", "nlme", "lme4", "car", "vegan", "DHARMa", "MASS", "gridExtra")

invisible(lapply(Pkgs2Load, library, character.only = TRUE))

#Set the working directory.
setwd([WORKING DIRECTORY])

#Import data files
PH <- read.csv2("Herb_sem_data_harvest.csv")
CC <- read.csv2("Herb_sem_data_insects.csv")

#Merge community and harvest data
PH.nometa <- PH[,c(1,9:11,13:38)]
PH.merge <- merge(CC, PH.nometa, by = "ID")
CC <- PH.merge

#Section 3: Prepare the data----
cols <- c("Location","Treatment","Cultivar","Field","Year")

#Subsection 3.1: Create variables and remove irrelevant variables
CC$Placement <- ifelse(CC$Row_number == "N/A", "Pixel", ifelse(CC$Row_number == "2" | CC$Row_number == "3", "Center", "Edge"))
CC$Year <- CC$Year2
names(CC)[names(CC)=="Field_number"] <- "Field"

CC$FWwrapper <- CC$`FW wrapper (g)` / 1000
CC$`FW wrapper (g)` <-NULL
CC$FWhead <- (CC$`FW clean head` + CC$`FW dmg head leaves`) / 1000
CC$FWdamhead <- CC$`FW dmg head leaves` / 1000
CC$Yieldloss <- CC$FWdamhead / CC$FWhead
CC$Yieldloss <- round(CC$Yieldloss * 100, digits = 0)

CC$Leaves1 <- CC$`#Leaves1`
CC$`#Leaves1` <- NULL
CC$Leaves2 <- CC$`#Leaves2`
CC$`#Leaves2` <- NULL
CC$Leaves3 <- CC$`#Leaves3`
CC$`#Leaves3` <- NULL
CC$Leaves4 <- CC$`#Leaves4`
CC$`#Leaves4` <- NULL
CC$Leaves5 <- CC$`#Leaves5`
CC$`#Leaves5` <- NULL

#Subsection 3.2: Change level Treatments
CC$Treatment <- factor(CC$Treatment, levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"))
CC$Treatment <- factor(CC$Treatment,
                       levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"),
                       labels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity", "Pixel"))
CC$Location <- factor(CC$Location, levels = c("Droevendaal", "Broekemahoeve"))

#Subsection 3.3: Change field names
CC$Field <- factor(CC$Field,
                   levels = c("1","2","3","5","10","J8_1","J8_3","J8_4","J9_2","J10_1"),
                   labels = c("1","2","3","4", "4","J9"  ,"J9"  ,"J8"  ,"J9" , "J10"))

#Subsection 3.4: Include Expect cv. with Rivera
CC$Cultivar[CC$Cultivar == "Expect"] <- "Rivera"
CC[cols] <- lapply(CC[cols], factor)

#Subsection 3.5: Remove replacement cabbages
CC$Replacement[is.na(CC$Replacement)] <- 0
CC <- subset(CC[CC$Replacement != 1,])

plantpar <- c("Radius1", "Radius2", "Radius3", "Radius4", "Radius5",
              "Leaves1", "Leaves2", "Leaves3", "Leaves4", "Leaves5",
              "Dmg(1-10)1", "Dmg(1-10)2", "Dmg(1-10)3", "Dmg(1-10)4", "Dmg(1-10)5")
CC[plantpar] <- lapply(CC[plantpar],as.numeric)

#Subsection 3.5.2: Remove cabbages that did not grow a head
CC <- subset(CC[CC$Head == 1,])

#Subsection 3.6: Add herbivores together
CC$Fb1 <- rowSums(CC[,c("Pha1", "Phu1")], na.rm = FALSE)
CC$Fb2 <- rowSums(CC[,c("Pha2", "Phu2")], na.rm = FALSE)
CC$Fb3 <- rowSums(CC[,c("Pha3", "Phu3")], na.rm = FALSE)
CC$Fb4 <- rowSums(CC[,c("Pha4", "Phu4")], na.rm = FALSE)
CC$Fb_early <- round(ifelse(is.na(CC$Fb1) == TRUE, CC$Fb2, (CC$Fb1 + CC$Fb2)/2), digits = 0)
CC$Fb_late <- round((CC$Fb3 + CC$Fb4)/2, digits = 0)
CC$LOG_Fb_early <- log(CC$Fb_early + 1)
CC$LOG_Fb_late <- log(CC$Fb_late + 1)

CC$Ch1 <- rowSums(CC[,c("Plx1", "Pr1", "Pb1", "Mb1", "Ag1", "Evergestis forficalis1", "Army_worm1", "Athalia1", "Weevil1")], na.rm = FALSE)
CC$Ch2 <- rowSums(CC[,c("Plx2", "Pr2", "Pb2", "Mb2", "Ag2", "Evergestis forficalis2", "Army_worm2", "Athalia2", "Weevil2")], na.rm = FALSE)
CC$Ch3 <- rowSums(CC[,c("Plx3", "Pr3", "Pb3", "Mb3", "Ag3", "Evergestis forficalis3", "Army_worm3", "Athalia3", "Weevil3")], na.rm = FALSE)
CC$Ch4 <- rowSums(CC[,c("Plx4", "Pr4", "Pb4", "Mb4", "Ag4", "Evergestis forficalis4", "Army_worm4", "Athalia4", "Weevil4")], na.rm = FALSE)
CC$Ch_early <- round(ifelse(is.na(CC$Ch1) == TRUE, CC$Ch2, (CC$Ch1 + CC$Ch2)/2), digits = 0)
CC$Ch_late <- round((CC$Ch3 + CC$Ch4)/2, digits = 0)
CC$LOG_Ch_early <- log(CC$Ch_early + 1)
CC$LOG_Ch_late <- log(CC$Ch_late + 1)

CC$Su1 <- rowSums(CC[,c("Bb1", "Mp1", "Mpn1", "Black1", "A_other1", "Wfly1", "Cicada1")], na.rm = TRUE)
CC$Su2 <- rowSums(CC[,c("Bb2", "Mp2", "Mpn2", "Black2", "A_other2", "Wfly2", "Cicada2")], na.rm = TRUE)
CC$Su3 <- rowSums(CC[,c("Bb3", "Mp3", "Mpn3", "Black3", "A_other3", "Wfly3", "Cicada3")], na.rm = TRUE)
CC$Su4 <- rowSums(CC[,c("Bb4", "Mp4", "Mpn4", "Black4", "A_other4", "Wfly4", "Cicada4")], na.rm = TRUE)
CC$Su_early <- round(ifelse(is.na(CC$Su1) == TRUE, CC$Su2, (CC$Su1 + CC$Su2)/2), digits = 0)
CC$Su_late <- round((CC$Su3 + CC$Su4)/2, digits = 0)
CC$LOG_Su_early <- log(CC$Su_early + 1)
CC$LOG_Su_late <- log(CC$Su_late + 1)

CC$Th_early <- round(ifelse(is.na(CC$Thrips1) == TRUE, CC$Thrips2, (CC$Thrips1 + CC$Thrips2)/2), digits = 0)
CC$Th_late <- round((CC$Thrips3 + CC$Thrips4)/2, digits = 0)
CC$LOG_Th_early <- log(CC$Th_early + 1)
CC$LOG_Th_late <- log(CC$Th_late + 1)

CC$LOG_FWhead <- log(CC$FWhead + 1)
CC$LOG_FWwrapper <- log(CC$FWwrapper + 1)

#Subsection 3.7: Remove N/A's 
CC <- CC[!is.na(CC$Radius3),]
CC <- CC[!is.na(CC$LOG_FWwrapper),]

#Subsection 3.8: Split CD vs Rivera from Treatment effects.
CCT <- CC[CC$Cultivar != "Christmas drumhead",]
CCT[cols] <- lapply(CCT[cols],factor)


#Subsection 3.9: Make subsets
#By location
CCT.droef <- subset(CCT[CCT$Location == "Droevendaal",])
CCT.broek <- subset(CCT[CCT$Location == "Broekemahoeve",])

#By treatment
CCT.Ref <- subset(CCT[CCT$Treatment == "Monoculture",])
CCT.Strip <- subset(CCT[CCT$Treatment == "Strip",])
CCT.SC <- subset(CCT[CCT$Treatment == "Strip_cultivar",])
CCT.SA <- subset(CCT[CCT$Treatment == "Strip_additive",])
CCT.SD <- subset(CCT[CCT$Treatment == "Strip_diversity",])
CCT.Pixel <- subset(CCT[CCT$Treatment == "Pixel",])

CCT.nopix <- subset(CCT[CCT$Treatment != "Pixel",])
#CCT.nopix <- subset(CCT.nopix[CCT.nopix$Treatment != "Strip_diversity",])
CCT.nopix[cols] <- lapply(CCT.nopix[cols],factor)

#By year
CCT.19 <- subset(CCT[CCT$Year == "2019",])
CCT.20 <- subset(CCT[CCT$Year == "2020",])
CCT.21 <- subset(CCT[CCT$Year == "2021",])

#Section 5: Model with functional groups ----
#Subsection 5.1: Main model (all data) ----
Func_Herb_all <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year + Location,
     data = CCT),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year + Location,
         data = CCT),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year + Location,
     data = CCT),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year + Location,
         data = CCT),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year + Location,
     data = CCT),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT
)

summary(Func_Herb_all, conserve = TRUE)

#Subsection 5.2: Model fitting ----
#Subsection 5.2.1: Year ----
Func_Herb_21 <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Location,
         data = CCT.21),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Location,
     data = CCT.21),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Location,
         data = CCT.21),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Location,
         data = CCT.21),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Location,
     data = CCT.21),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Location,
         data = CCT.21),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Location,
         data = CCT.21), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Location,
         data = CCT.21),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Location,
         data = CCT.21),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Location,
         data = CCT.21),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Location,
     data = CCT.21),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  #LOG_Su_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.21
)

summary(Func_Herb_21, conserve = TRUE)

#19 20 21
#Subsection 5.2.2: Location (incl. Strip_diversity) ----
Func_Herb_droef <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year,
         data = CCT.droef),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year,
     data = CCT.droef),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year,
         data = CCT.droef),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year,
         data = CCT.droef),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year,
     data = CCT.droef),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year,
         data = CCT.droef),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year,
         data = CCT.droef), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year,
         data = CCT.droef),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year,
         data = CCT.droef),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year,
         data = CCT.droef),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year,
     data = CCT.droef),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  #LOG_Su_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.droef
)

summary(Func_Herb_droef, conserve = TRUE)

#droef broek SD
#Subsection 5.2.3: Treatment (except Strip_diversity) ----
Func_Herb_SA <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.SA),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.SA),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.SA),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year + Location,
         data = CCT.SA),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year + Location,
     data = CCT.SA),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year + Location,
     data = CCT.SA),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  #LOG_Su_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.SA
)

summary(Func_Herb_SA, conserve = TRUE)

#Ref Strip SC SA

#Subsection 5.3: Run models per treatment ----
#Subsection 5.3.1: Monoculture
Func_Herb_Ref <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.Ref),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.Ref),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.Ref),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year + Location,
         data = CCT.Ref),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year + Location,
     data = CCT.Ref),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.Ref),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.Ref), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.Ref),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.Ref),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year + Location,
         data = CCT.Ref),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year + Location,
     data = CCT.Ref),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.Ref
)

Ref.Summary <- summary(Func_Herb_Ref, conserve = TRUE)

#Subsection 5.3.2: Strip
Func_Herb_Strip <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.Strip),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.Strip),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.Strip),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year + Location,
         data = CCT.Strip),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year + Location,
     data = CCT.Strip),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.Strip),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.Strip), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.Strip),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.Strip),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year + Location,
         data = CCT.Strip),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year + Location,
     data = CCT.Strip),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.Strip
)

Strip.Summary <- summary(Func_Herb_Strip, conserve = TRUE)

#Subsection 5.3.3: Strip_cultivar
Func_Herb_SC <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.SC),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.SC),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.SC),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year + Location,
         data = CCT.SC),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year + Location,
     data = CCT.SC),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.SC),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.SC), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.SC),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.SC),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year + Location,
         data = CCT.SC),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year + Location,
     data = CCT.SC),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.SC
)

SC.Summary <- summary(Func_Herb_SC, conserve = TRUE)

#Subsection 5.3.4: Strip_additive
Func_Herb_SA <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.SA),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.SA),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year + Location,
         data = CCT.SA),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year + Location,
         data = CCT.SA),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year + Location,
     data = CCT.SA),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year + Location,
         data = CCT.SA),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year + Location,
     data = CCT.SA),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.SA
)

SA.Summary <- summary(Func_Herb_SA, conserve = TRUE)

#Subsection 5.3.5: Strip_diversity
Func_Herb_SD <- psem(
  #M1
  glm.nb(Ch_early ~ Radius2 + Leaves2 + Year,
         data = CCT.SD),
  
  #M2
  lm(LOG_Su_early ~ Radius2 + Leaves2 + Year,
     data = CCT.SD),
  
  #M3
  glm.nb(Th_early ~ Radius2 + Leaves2 + Year,
         data = CCT.SD),
  
  #M4
  glm.nb(Fb_early ~ Radius2 + Year,
         data = CCT.SD),
  
  #M5
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Ch_early + Fb_early + Year,
     data = CCT.SD),
  
  #M6
  glm.nb(Ch_late ~ Radius2 + Ch_early + LOG_Su_early + LOG_FWwrapper + Year,
         data = CCT.SD),
  
  #M7
  glm.nb(Su_late ~ Radius2 + Ch_early + LOG_Su_early + Th_early + Fb_early + LOG_FWwrapper + Year,
         data = CCT.SD), 
  
  #M8
  glm.nb(Th_late ~ Ch_early + LOG_Su_early + LOG_FWwrapper + Year,
         data = CCT.SD),
  
  #M9
  glm.nb(Fb_late ~ Radius2 + Leaves2 + Ch_early + LOG_Su_early + Fb_early + LOG_FWwrapper + Year,
         data = CCT.SD),
  
  #M10
  glm.nb(Yieldloss ~ Ch_early + LOG_FWwrapper + Year,
         data = CCT.SD),
  
  #M11
  lm(LOG_FWhead ~ Radius2 + Leaves2 + Ch_early + LOG_FWwrapper + Ch_late + Th_late + Fb_late + Yieldloss + Year,
     data = CCT.SD),
  
  
  # Correlated structures
  Ch_early %~~% LOG_Su_early,
  Ch_early %~~% Th_early,
  Ch_early %~~% Fb_early,
  Ch_late %~~% Th_late,
  Su_late %~~% Fb_late,
  Th_late %~~% Fb_late,
  Ch_late %~~% Su_late,
  data = CCT.SD
)

SD.Summary <- summary(Func_Herb_SD, conserve = TRUE)
#Section 6: Make figures ----
#Subsection 6.1: Preparations ----
#Colours for treatments
Droef.colors <- c("#895F39", "#B6D663", "#27a6b0", "#213F9A", "#9671B2") #, "#B32E5F")

#Identify summary output that is not useful
Not.Interesting <- c("Year",
                     "Year = 2021",
                     "Year = 2020",
                     "Year = 2019",
                     "Location",
                     "Location = Droevendaal",
                     "Location = Broekemahoeve",
                     "~~LOG_Su_early",
                     "~~Th_early",
                     "~~Fb_early",
                     "~~Th_late",
                     "~~Fb_late",
                     "~~Su_late")

#Remove output that is not useful from treatment summaries
`%notin%` <- Negate(`%in%`)
Paths.Ref <- subset(as.data.frame(Ref.Summary$coefficients), 
                    Predictor %notin% Not.Interesting)
Paths.Strip <- subset(as.data.frame(Strip.Summary$coefficients), 
                      Predictor %notin% Not.Interesting)
Paths.SC <- subset(as.data.frame(SC.Summary$coefficients), 
                   Predictor %notin% Not.Interesting)
Paths.SA <- subset(as.data.frame(SA.Summary$coefficients), 
                   Predictor %notin% Not.Interesting)
Paths.SD <- subset(as.data.frame(SD.Summary$coefficients), 
                   Predictor %notin% Not.Interesting)

#Annotate the subset with the treatment
Paths.Ref$Treatment <- "Monoculture"
Paths.Strip$Treatment <- "Strip"
Paths.SC$Treatment <- "Strip_cultivar"
Paths.SA$Treatment <- "Strip_additive"
Paths.SD$Treatment <- "Strip_diversity"

#Annotate each path with a unique name identifying the path
Paths.Ref$Pathway <- interaction(Paths.Ref$Response, Paths.Ref$Predictor)
Paths.Strip$Pathway <- interaction(Paths.Strip$Response, Paths.Strip$Predictor)
Paths.SC$Pathway <- interaction(Paths.SC$Response, Paths.SC$Predictor)
Paths.SA$Pathway <- interaction(Paths.SA$Response, Paths.SA$Predictor)
Paths.SD$Pathway <- interaction(Paths.SD$Response, Paths.SD$Predictor)

#Bind the results in a larger data frame
combined.results <- rbind(Paths.Ref,
                          Paths.Strip,
                          Paths.SC,
                          Paths.SA,
                          Paths.SD)
combined.results$Pathway <- factor(combined.results$Pathway)
para <- c("Estimate","Std.Error","Std.Estimate")
combined.results[para] <- lapply(combined.results[para], as.numeric)
Paths.Strip[para] <- lapply(Paths.Strip[para], as.numeric)
combined.results$Treatment <- factor(combined.results$Treatment, levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"))

#Create list of all pathways (40 in this model)
Different.Paths <- levels(combined.results$Pathway)


#Subsection 6.2: Figures per parameter ---- 
#Create a list that stores the plots
All_Paths_Plotted <- vector(mode = "list", length = 40)

# Start the loop 
for (i in 1:length(Different.Paths)) {
  
  # Select the path for which results should be plotted
  Path <- subset(combined.results, Pathway == Different.Paths[i])
  
  # Select the path for the control treatment separately (this will be our baseline reference) 
  Strip.Path <- subset(Paths.Strip, Pathway == Different.Paths[i])
  
  
  # Plot with ggplot
  All_Paths_Plotted[[i]] <- 
    ggplot() +
    # The value of the estimate and its 95% interval for each treatment (but not control)
    geom_point(data = Path, aes(x = Treatment, y = Estimate, colour = Treatment)) +
    geom_errorbar(data = Path, aes(x = Treatment,
                                   ymin = Estimate - 1.96*Std.Error, 
                                   ymax = Estimate + 1.96*Std.Error, 
                                   colour = Treatment), 
                  width=.2) +
    # The estimated value of the path for control plants, with 95% interval
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate)) + 
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate - 1.96 * Std.Error), linetype = 2) + 
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate + 1.96 * Std.Error), linetype = 2) + 
    
    # Add some color and a nice layout of the figure
    labs(title = Different.Paths[i],x = "Cropping design", y = "Estimate") +
    scale_colour_manual(values = Droef.colors) +
    guides(colour = "none") +
    
    # This is a custom theme I specified. You can replace this with your own theme or 
    # "theme_bw()" or something similar.
    theme_bw()
  
}

# Define the layout of the plots 
Path_Plots_layout <- rbind(c(1:6),c(7:12),c(13:18),c(19:24),c(25:30),c(31:36),c(37:42)) 
Paths_Plotted <- marrangeGrob(All_Paths_Plotted, nrow = 7, ncol = 6,layout_matrix = Path_Plots_layout)

# Visualize the plots
png(filename = "Model 3 - Differences paths.png", width = 6000, height = 7000, res = 400)
Paths_Plotted
dev.off()

#subsection 6.3: Pathway comparison effect on yield----
All_Effects <- data.frame(matrix(nrow = 12, ncol = 0))

Treatment_Levels <- levels(combined.results$Treatment)

for (i in 1:length(Treatment_Levels)){
  
  # Select the treatment
  Path_Data <- subset(combined.results, Treatment == Treatment_Levels[i])
  
  # Effects of each variable on seed production
  # This is the same calculation you would do in Excel and requires you to 
  # write all of this stuff out for each SEM structure you want to use.
  
  # Proportion Damaged Head Weight
  PDW_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Yieldloss"),]$Std.Estimate
  PDW_Indirect <- 0
  PDW_Total <- PDW_Direct + PDW_Indirect
  
  # Late flea beetle abundance
  LFB_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Fb_late"),]$Std.Estimate
  LFB_Indirect <- 
    # Path over proportion Damaged Head Weight
    0 
  LFB_Total <- LFB_Direct + LFB_Indirect
  
  # Late thrips abundance
  LTH_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Th_late"),]$Std.Estimate
  LTH_Indirect <- 
    # Path over proportion Damaged Head Weight
    0
  LTH_Total <- LTH_Direct + LTH_Indirect
  
  # Late sucker abundance
  LSU_Direct <- 0
  LSU_Indirect <- 
    # Path over proportion Damaged Head Weight
    0 
  LSU_Total <- LSU_Direct + LSU_Indirect
  
  # Late chewer abundance
  LCH_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Ch_late"),]$Std.Estimate
  LCH_Indirect <- 
    # Path over proportion Damaged Head Weight
    0
  LCH_Total <- LCH_Direct + LCH_Indirect
  
  # Fresh weight wrapper leaves
  FWW_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.LOG_FWwrapper"),]$Std.Estimate
  FWW_Indirect <- 
    # Path over proportion Damaged Head Weight
    Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_FWwrapper"),]$Std.Estimate * PDW_Total +
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.LOG_FWwrapper"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_late.LOG_FWwrapper"),]$Std.Estimate * LTH_Total +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.LOG_FWwrapper"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.LOG_FWwrapper"),]$Std.Estimate * LCH_Total 
  FWW_Total <- FWW_Direct + FWW_Indirect
  
  # Early flea beetle abundance
  EFB_Direct <- 0
  EFB_Indirect <- 
    # Path over proportion Damaged Head Weight
    0 + 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Fb_early"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.Fb_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    0 +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Fb_early"),]$Std.Estimate * FWW_Total
  EFB_Total <- EFB_Direct + EFB_Indirect
  
  # Early thrips abundance
  ETH_Direct <- 0
  ETH_Indirect <- 
    # Path over proportion Damaged Head Weight
    0 + 
    # Path over late flea beetle abundance
    0 +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.Th_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    0 +
    # Path over fresh weight wrapper
    0
  ETH_Total <- ETH_Direct + ETH_Indirect

  # Early sucker abundance
  ESU_Direct <- 0
  ESU_Indirect <- 
    # Path over proportion Damaged Head Weight
    0 + 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.LOG_Su_early"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_late.LOG_Su_early"),]$Std.Estimate * LTH_Total +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.LOG_Su_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.LOG_Su_early"),]$Std.Estimate * LCH_Total +
    # Path over fresh weight wrapper
    0
  ESU_Total <- ESU_Direct + ESU_Indirect
  
  # Early chewer abundance
  ECH_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Ch_early"),]$Std.Estimate
  ECH_Indirect <- 
    # Path over proportion Damaged Head Weight
    Path_Data[which(Path_Data$Pathway == "Yieldloss.Ch_early"),]$Std.Estimate * PDW_Total + 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Ch_early"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_late.Ch_early"),]$Std.Estimate * LTH_Total +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.Ch_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.Ch_early"),]$Std.Estimate * LCH_Total +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Ch_early"),]$Std.Estimate * FWW_Total
  ECH_Total <- ECH_Direct + ECH_Indirect  
  
  # Leaves T2
  L2_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Leaves2"),]$Std.Estimate
  L2_Indirect <- 
    # Path over proportion Damaged Head Weight
    0 + 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Leaves2"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    0 +
    # Path over late chewer abundance
    0 +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Leaves2"),]$Std.Estimate * FWW_Total +
    # Path over early flea beetle abundance
    0 +
    # Path over early thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_early.Leaves2"),]$Std.Estimate * ETH_Total +
    # Path over early sucker abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Su_early.Leaves2"),]$Std.Estimate * ESU_Total +
    # Path over early chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_early.Leaves2"),]$Std.Estimate * ECH_Total 
  L2_Total <- L2_Direct + L2_Indirect
  
  # Radius T2
  R2_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Radius2"),]$Std.Estimate 
  R2_Indirect <- 
    # Path over proportion Damaged Head Weight
    0 + 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Radius2"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    0 +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.Radius2"),]$Std.Estimate * LCH_Total +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Radius2"),]$Std.Estimate * FWW_Total +
    # Path over early flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_early.Radius2"),]$Std.Estimate * ETH_Total +
    # Path over early thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_early.Radius2"),]$Std.Estimate * ETH_Total +
    # Path over early sucker abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Su_early.Radius2"),]$Std.Estimate * ESU_Total +
    # Path over early chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_early.Radius2"),]$Std.Estimate * ECH_Total 
  R2_Total <- R2_Direct + R2_Indirect
  
  # Store all the total effects in a dataframe
  Path_Effects <- as.data.frame(rbind(R2_Total,
                                      L2_Total,
                                      ECH_Total,
                                      ESU_Total,
                                      ETH_Total,
                                      EFB_Total,
                                      FWW_Total,
                                      LCH_Total,
                                      LSU_Total,
                                      LTH_Total,
                                      LFB_Total,
                                      PDW_Total))
  
  # Annotate the dataframe with the treatment name
  colnames(Path_Effects) <- Treatment_Levels[i]
  
  # Store the result in a bigger dataframe that stores info for each iteration of the for loop
  All_Effects <- cbind(All_Effects,Path_Effects)
  
}

# Wrangle the resulting data frame into the right shape for a heatmap
Stacked_Effects <- data.frame("Treatment" = as.data.frame(stack(All_Effects))$ind,
                              "Path" = c("Early diameter",
                                         "Early number\nof leaves",
                                         "Early chewer\nabundance",
                                         "Early sucker\nabundance",
                                         "Early thrips\nabundance",
                                         "Early flea\nbeetle abundance",
                                         "Fresh weight\nwrapper leaves",
                                         "Late chewer\nabundance",
                                         "Late sucker\nabundance",
                                         "Late thrips\nabundance",
                                         "Late flea\nbeetle abundance",
                                         "Proportion\ndamaged\nhead weight"),
                              "TotalEffect" = as.data.frame(stack(All_Effects))$values)

# Plot a heatmap using ggplot
Stacked_Effects$Treatment2 <- factor(Stacked_Effects$Treatment, 
                                     levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"),
                                     labels = c("Monoculture", "Strip", "Strip\ncultivar", "Strip\nadditive", "Strip\ndiversity"))
Stacked_Effects$Path <- factor(Stacked_Effects$Path, levels = c("Early diameter",
                                                                "Early number\nof leaves",
                                                                "Early chewer\nabundance",
                                                                "Early sucker\nabundance",
                                                                "Early thrips\nabundance",
                                                                "Early flea\nbeetle abundance",
                                                                "Fresh weight\nwrapper leaves",
                                                                "Late chewer\nabundance",
                                                                "Late sucker\nabundance",
                                                                "Late thrips\nabundance",
                                                                "Late flea\nbeetle abundance",
                                                                "Proportion\ndamaged\nhead weight"))

pdf(file = "Model 3 - Effect on FW head.pdf", width = 14, height = 25.2)
ggplot(data = Stacked_Effects, aes(x = Treatment2, y = Path, fill = TotalEffect)) +
  geom_tile() +
  # Add the total effects (rounded to 2 numbers after the decimal point)
  geom_text(aes(label = sprintf("%.2f",TotalEffect)), size = 8) +
  scale_fill_gradient2(name = "Effect on\nfresh weight\nhead",
                       low = "#A51122",
                       mid = "#FFFFFF",
                       high = "#006228",
                       limits = c(-1, 1), 
                       breaks = seq(-1,1,by=0.5)) + 
  theme_bw() +
  theme(axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text = element_text(size = 25),
        legend.title = element_text(size = 20), legend.text = element_text(size = 12)) +
  guides(size = "none")
dev.off()

#subsection 6.4: Pathway comparison effect on proportion Damaged Head Weight----
All_Effects <- data.frame(matrix(nrow = 11, ncol = 0))

Treatment_Levels <- levels(combined.results$Treatment)

for (i in 1:length(Treatment_Levels)){
  
  # Select the treatment
  Path_Data <- subset(combined.results, Treatment == Treatment_Levels[i])
  
  # Effects of each variable on seed production
  # This is the same calculation you would do in Excel and requires you to 
  # write all of this stuff out for each SEM structure you want to use.

  # Late flea beetle abundance
  LFB_Direct <- 0
  LFB_Indirect <- 0
  LFB_Total <- LFB_Direct + LFB_Indirect
  
  # Late thrips abundance
  LTH_Direct <- 0
  LTH_Indirect <- 0
  LTH_Total <- LTH_Direct + LTH_Indirect
  
  # Late sucker abundance
  LSU_Direct <- 0
  LSU_Indirect <- 0
  LSU_Total <- LSU_Direct + LSU_Indirect
  
  # Late chewer abundance
  LCH_Direct <- 0
  LCH_Indirect <- 0
  LCH_Total <- LCH_Direct + LCH_Indirect
  
  # Fresh weight wrapper leaves
  FWW_Direct <- Path_Data[which(Path_Data$Pathway == "Yieldloss.LOG_FWwrapper"),]$Std.Estimate
  FWW_Indirect <- 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.LOG_FWwrapper"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_late.LOG_FWwrapper"),]$Std.Estimate * LTH_Total +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.LOG_FWwrapper"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.LOG_FWwrapper"),]$Std.Estimate * LCH_Total 
  FWW_Total <- FWW_Direct + FWW_Indirect
  
  # Early flea beetle abundance
  EFB_Direct <- 0
  EFB_Indirect <- 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Fb_early"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.Fb_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    0 +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Fb_early"),]$Std.Estimate * FWW_Total
  EFB_Total <- EFB_Direct + EFB_Indirect
  
  # Early thrips abundance
  ETH_Direct <- 0
  ETH_Indirect <- 0
    # Path over late flea beetle abundance
    0 +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.Th_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    0 +
    # Path over fresh weight wrapper
    0
  ETH_Total <- ETH_Direct + ETH_Indirect
  
  # Early sucker abundance
  ESU_Direct <- 0
  ESU_Indirect <- 0
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.LOG_Su_early"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_late.LOG_Su_early"),]$Std.Estimate * LTH_Total +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.LOG_Su_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.LOG_Su_early"),]$Std.Estimate * LCH_Total +
    # Path over fresh weight wrapper
    0
  ESU_Total <- ESU_Direct + ESU_Indirect
  
  # Early chewer abundance
  ECH_Direct <- Path_Data[which(Path_Data$Pathway == "Yieldloss.Ch_early"),]$Std.Estimate
  ECH_Indirect <-  
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Ch_early"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_late.Ch_early"),]$Std.Estimate * LTH_Total +
    # Path over late sucker abundance
    Path_Data[which(Path_Data$Pathway == "Su_late.Ch_early"),]$Std.Estimate * LSU_Total +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.Ch_early"),]$Std.Estimate * LCH_Total +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Ch_early"),]$Std.Estimate * FWW_Total
  ECH_Total <- ECH_Direct + ECH_Indirect  
  
  # Leaves T2
  L2_Direct <- 0
  L2_Indirect <- 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Leaves2"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    0 +
    # Path over late chewer abundance
    0 +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Leaves2"),]$Std.Estimate * FWW_Total +
    # Path over early flea beetle abundance
    0 +
    # Path over early thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_early.Leaves2"),]$Std.Estimate * ETH_Total +
    # Path over early sucker abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Su_early.Leaves2"),]$Std.Estimate * ESU_Total +
    # Path over early chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_early.Leaves2"),]$Std.Estimate * ECH_Total 
  L2_Total <- L2_Direct + L2_Indirect
  
  # Radius T2
  R2_Direct <- 0
  R2_Indirect <- 
    # Path over late flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_late.Radius2"),]$Std.Estimate * LFB_Total +
    # Path over late thrips abundance
    0 +
    # Path over late sucker abundance
    0 +
    # Path over late chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_late.Radius2"),]$Std.Estimate * LCH_Total +
    # Path over fresh weight wrapper
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Radius2"),]$Std.Estimate * FWW_Total +
    # Path over early flea beetle abundance
    Path_Data[which(Path_Data$Pathway == "Fb_early.Radius2"),]$Std.Estimate * ETH_Total +
    # Path over early thrips abundance
    Path_Data[which(Path_Data$Pathway == "Th_early.Radius2"),]$Std.Estimate * ETH_Total +
    # Path over early sucker abundance
    Path_Data[which(Path_Data$Pathway == "LOG_Su_early.Radius2"),]$Std.Estimate * ESU_Total +
    # Path over early chewer abundance
    Path_Data[which(Path_Data$Pathway == "Ch_early.Radius2"),]$Std.Estimate * ECH_Total 
  R2_Total <- R2_Direct + R2_Indirect
  
  # Store all the total effects in a dataframe
  Path_Effects <- as.data.frame(rbind(R2_Total,
                                      L2_Total,
                                      ECH_Total,
                                      ESU_Total,
                                      ETH_Total,
                                      EFB_Total,
                                      FWW_Total,
                                      LCH_Total,
                                      LSU_Total,
                                      LTH_Total,
                                      LFB_Total))
  
  # Annotate the dataframe with the treatment name
  colnames(Path_Effects) <- Treatment_Levels[i]
  
  # Store the result in a bigger dataframe that stores info for each iteration of the for loop
  All_Effects <- cbind(All_Effects,Path_Effects)
  
}

# Wrangle the resulting data frame into the right shape for a heatmap
Stacked_Effects <- data.frame("Treatment" = as.data.frame(stack(All_Effects))$ind,
                              "Path" = c("Early diameter",
                                         "Early number\nof leaves",
                                         "Early chewer\nabundance",
                                         "Early sucker\nabundance",
                                         "Early thrips\nabundance",
                                         "Early flea\nbeetle abundance",
                                         "Fresh weight\nwrapper leaves",
                                         "Late chewer\nabundance",
                                         "Late sucker\nabundance",
                                         "Late thrips\nabundance",
                                         "Late flea\nbeetle abundance"),
                              "TotalEffect" = as.data.frame(stack(All_Effects))$values)

# Plot a heatmap using ggplot
Stacked_Effects$Treatment2 <- factor(Stacked_Effects$Treatment, 
                                     levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"),
                                     labels = c("Monoculture", "Strip", "Strip\ncultivar", "Strip\nadditive", "Strip\ndiversity"))
Stacked_Effects$Path <- factor(Stacked_Effects$Path, levels = c("Early diameter",
                                                                "Early number\nof leaves",
                                                                "Early chewer\nabundance",
                                                                "Early sucker\nabundance",
                                                                "Early thrips\nabundance",
                                                                "Early flea\nbeetle abundance",
                                                                "Fresh weight\nwrapper leaves",
                                                                "Late chewer\nabundance",
                                                                "Late sucker\nabundance",
                                                                "Late thrips\nabundance",
                                                                "Late flea\nbeetle abundance"))

pdf(file = "Model 3 - Effect on proportion damaged head weight.pdf", width = 14, height = 23.1777777)
ggplot(data = Stacked_Effects, aes(x = Treatment2, y = Path, fill = TotalEffect)) +
  geom_tile() +
  # Add the total effects (rounded to 2 numbers after the decimal point)
  geom_text(aes(label = sprintf("%.2f",TotalEffect)), size = 8) +
  scale_fill_gradient2(name = "Effect on\ndamaged\nhead weight",
                       low = "#A51122",
                       mid = "#FFFFFF",
                       high = "#006228",
                       limits = c(-1, 1), 
                       breaks = seq(-1,1,by=0.5)) + 
  theme_bw() +
  theme(axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text = element_text(size = 25),
        legend.title = element_text(size = 20), legend.text = element_text(size = 12)) +
  guides(size = "none")
dev.off()
