#Section 1: Create clean R workspace ----
rm(list=ls())
graphics.off()
gc(FALSE)
cat("\014")
Sys.setenv(LANG = "en")
options(max.print = 2000)

#Section 2: Open libraries and datasets ----
Pkgs2Load <- c("ggplot2", "ggm", "lavaan", "piecewiseSEM", "nlme", "lme4", "car", "vegan", "DHARMa", "MASS", "gridExtra")

invisible(lapply(Pkgs2Load, library, character.only = TRUE))

#Set the working directory.
setwd([WORKING DIRECTORY])

#Import data files
PH <- read.csv2("Herb_sem_data_harvest.csv")
CC <- read.csv2("Herb_sem_data_insects.csv")

#Merge community and harvest data
PH.nometa <- PH[,c(1,9:11,13:38)]
PH.merge <- merge(CC, PH.nometa, by = "ID")
CC <- PH.merge

#Section 3: Prepare the data----
cols <- c("Location","Treatment","Cultivar","Field","Year")

#Subsection 3.1: Create variables and remove irrelevant variables
CC$Placement <- ifelse(CC$Row_number == "N/A", "Pixel", ifelse(CC$Row_number == "2" | CC$Row_number == "3", "Center", "Edge"))
CC$Year <- CC$Year2
names(CC)[names(CC)=="Field_number"] <- "Field"

CC$FWwrapper <- CC$`FW wrapper (g)` / 1000
CC$`FW wrapper (g)` <-NULL
CC$FWhead <- (CC$`FW clean head` + CC$`FW dmg head leaves`) / 1000

CC$Leaves1 <- CC$`#Leaves1`
CC$`#Leaves1` <- NULL
CC$Leaves2 <- CC$`#Leaves2`
CC$`#Leaves2` <- NULL
CC$Leaves3 <- CC$`#Leaves3`
CC$`#Leaves3` <- NULL
CC$Leaves4 <- CC$`#Leaves4`
CC$`#Leaves4` <- NULL
CC$Leaves5 <- CC$`#Leaves5`
CC$`#Leaves5` <- NULL

#Subsection 3.2: Change level Treatments
CC$Treatment <- factor(CC$Treatment, levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"))
CC$Treatment <- factor(CC$Treatment,
                       levels = c("REF_SPACE", "STRIP", "STRIP_VAR", "STRIP_ADD", "STRIP_ROT", "PIXEL"),
                       labels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity", "Pixel"))
CC$Location <- factor(CC$Location, levels = c("Droevendaal", "Broekemahoeve"))

#Subsection 3.3: Change field names
CC$Field <- factor(CC$Field,
                   levels = c("1","2","3","5","10","J8_1","J8_3","J8_4","J9_2","J10_1"),
                   labels = c("1","2","3","4", "4","J9"  ,"J9"  ,"J8"  ,"J9" , "J10"))

#Subsection 3.4: Include Expect cv. with Rivera
CC$Cultivar[CC$Cultivar == "Expect"] <- "Rivera"
CC[cols] <- lapply(CC[cols], factor)

#Subsection 3.5: Remove replacement cabbages
CC$Replacement[is.na(CC$Replacement)] <- 0
CC <- subset(CC[CC$Replacement != 1,])

plantpar <- c("Radius1", "Radius2", "Radius3", "Radius4", "Radius5",
              "Leaves1", "Leaves2", "Leaves3", "Leaves4", "Leaves5",
              "Dmg(1-10)1", "Dmg(1-10)2", "Dmg(1-10)3", "Dmg(1-10)4", "Dmg(1-10)5")
CC[plantpar] <- lapply(CC[plantpar],as.numeric)

#Subsection 3.5.2: Remove cabbages that did not grow a head
CC <- subset(CC[CC$Head == 1,])

#Subsection 3.6: Log transform weights
CC$LOG_FWhead <- log(CC$FWhead + 1)
CC$LOG_FWwrapper <- log(CC$FWwrapper + 1)

#Subsection 3.7: Remove N/A's 
CC <- CC[!is.na(CC$Radius3),]
CC <- CC[!is.na(CC$LOG_FWwrapper),]

#Subsection 3.8: Split CD vs Rivera from Treatment effects.
CCT <- CC[CC$Cultivar != "Christmas drumhead",]
CCT[cols] <- lapply(CCT[cols],factor)


#Subsection 3.9: Make subsets
#By treatment
CCT.Ref <- subset(CCT[CCT$Treatment == "Monoculture",])
CCT.Strip <- subset(CCT[CCT$Treatment == "Strip",])
CCT.SC <- subset(CCT[CCT$Treatment == "Strip_cultivar",])
CCT.SA <- subset(CCT[CCT$Treatment == "Strip_additive",])
CCT.SD <- subset(CCT[CCT$Treatment == "Strip_diversity",])
CCT.Pixel <- subset(CCT[CCT$Treatment == "Pixel",])

CCT.nopix <- subset(CCT[CCT$Treatment != "Pixel",])
CCT.nopix[cols] <- lapply(CCT.nopix[cols],factor)

#By year
CCT.19 <- subset(CCT.nopix[CCT.nopix$Year == "2019",])
CCT.20 <- subset(CCT.nopix[CCT.nopix$Year == "2020",])
CCT.21 <- subset(CCT.nopix[CCT.nopix$Year == "2021",])

#By location
CCT.droef <- subset(CCT.nopix[CCT.nopix$Location == "Droevendaal",])
CCT.broek <- subset(CCT.nopix[CCT.nopix$Location == "Broekemahoeve",])


#Section 5: Model without herbivores ----
#Subsection 5.1: Main model (all data) ----
NoHerb_all <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.nopix),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Year + Location,
     data = CCT.nopix),
  
  #M3
  #glm.nb(Yieldloss ~ Year + Location,
  #       data = CCT.nopix),
  
  
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.nopix
)

summary(NoHerb_all, conserve = TRUE)


#Subsection 5.2: Model fitting ----
#Subsection 5.2.1: Years
NoHerb_21 <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Location,
     data = CCT.21),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Location,
     data = CCT.21),
  
  #M3
  #glm.nb(Yieldloss ~ Location,
  #       data = CCT.21),
  
  
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.21
)

summary(NoHerb_21, conserve = TRUE)


#Subsection 5.2.2: Locations
NoHerb_broek <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Year,
     data = CCT.broek),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Year,
     data = CCT.broek),
  
  #M3
  #glm.nb(Yieldloss ~ Year,
  #       data = CCT.broek),
  
  
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.broek
)

summary(NoHerb_broek, conserve = TRUE)


#Subsection 5.3: Run model per treatment ----
#Subsection 5.3.1: Monoculture
NoHerb_Ref <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.Ref),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Year + Location,
     data = CCT.Ref),
  
  #M3
  #glm.nb(Yieldloss ~ Year + Location,
  #       data = CCT.Ref),
  
  
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.Ref
)

Ref.Summary <- summary(NoHerb_Ref, conserve = TRUE)


#Subsection 5.3.2: Strip
NoHerb_Strip <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.Strip),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Year + Location,
     data = CCT.Strip),
  
  #M3
  #glm.nb(Yieldloss ~ Year + Location,
  #       data = CCT.Strip),
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.Strip
)

Strip.Summary <- summary(NoHerb_Strip, conserve = TRUE)


#Subsection 5.3.3: Strip_cultivar
NoHerb_SC <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.SC),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Year + Location,
     data = CCT.SC),
  
  #M3
  #glm.nb(Yieldloss ~ Year + Location,
  #       data = CCT.SC),
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.SC
)

SC.Summary <- summary(NoHerb_SC, conserve = TRUE)


#Subsection 5.3.4: Strip_additive
NoHerb_SA <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Year + Location,
     data = CCT.SA),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Year + Location,
     data = CCT.SA),
  
  #M3
  #glm.nb(Yieldloss ~ Year + Location,
  #       data = CCT.SA),
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.SA
)

SA.Summary <- summary(NoHerb_SA, conserve = TRUE)


#Subsection 5.3.5: Strip_diversity
NoHerb_SD <- psem(
  
  #M1
  lm(LOG_FWwrapper ~ Radius2 + Leaves2 + Year,
     data = CCT.SD),
  
  #M2
  lm(LOG_FWhead ~ Radius2 + Leaves2 + LOG_FWwrapper + Year,
     data = CCT.SD),
  
  #M3
  #glm.nb(Yieldloss ~ Year,
  #       data = CCT.SD),
  
  # Correlated structures
  #Yieldloss %~~% LOG_FWhead,
  data = CCT.SD
)

SD.Summary <- summary(NoHerb_SD, conserve = TRUE)

#Section 6: Make figures ----
#Subsection 6.1: Preperations ----
#Colours for treatments
Droef.colors <- c("#895F39", "#B6D663", "#27a6b0", "#213F9A", "#9671B2") #, "#B32E5F")

#Identify summary output that is not useful
Not.Interesting <- c("Year",
                     "Year = 2021",
                     "Year = 2020",
                     "Year = 2019",
                     "Location",
                     "Location = Droevendaal",
                     "Location = Broekemahoeve")

#Remove output that is not useful from treatment summaries
`%notin%` <- Negate(`%in%`)
Paths.Ref <- subset(as.data.frame(Ref.Summary$coefficients), 
                        Predictor %notin% Not.Interesting)
Paths.Strip <- subset(as.data.frame(Strip.Summary$coefficients), 
                    Predictor %notin% Not.Interesting)
Paths.SC <- subset(as.data.frame(SC.Summary$coefficients), 
                    Predictor %notin% Not.Interesting)
Paths.SA <- subset(as.data.frame(SA.Summary$coefficients), 
                    Predictor %notin% Not.Interesting)
Paths.SD <- subset(as.data.frame(SD.Summary$coefficients), 
                    Predictor %notin% Not.Interesting)

#Annotate the subset with the treatment
Paths.Ref$Treatment <- "Monoculture"
Paths.Strip$Treatment <- "Strip"
Paths.SC$Treatment <- "Strip_cultivar"
Paths.SA$Treatment <- "Strip_additive"
Paths.SD$Treatment <- "Strip_diversity"

#Annotate each path with a unique name identifying the path
Paths.Ref$Pathway <- interaction(Paths.Ref$Response, Paths.Ref$Predictor)
Paths.Strip$Pathway <- interaction(Paths.Strip$Response, Paths.Strip$Predictor)
Paths.SC$Pathway <- interaction(Paths.SC$Response, Paths.SC$Predictor)
Paths.SA$Pathway <- interaction(Paths.SA$Response, Paths.SA$Predictor)
Paths.SD$Pathway <- interaction(Paths.SD$Response, Paths.SD$Predictor)

#Bind the results in a larger data frame
combined.results <- rbind(Paths.Ref,
                          Paths.Strip,
                          Paths.SC,
                          Paths.SA,
                          Paths.SD)
combined.results$Pathway <- factor(combined.results$Pathway)
para <- c("Estimate","Std.Error","Std.Estimate")
combined.results[para] <- lapply(combined.results[para], as.numeric)
Paths.Strip[para] <- lapply(Paths.Strip[para], as.numeric)
combined.results$Treatment <- factor(combined.results$Treatment, levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"))

#Create list of all pathways (5 in this model)
Different.Paths <- levels(combined.results$Pathway)


#Subsection 6.2: Figures per parameter ---- 
#Create a list that stores the plots
All_Paths_Plotted <- vector(mode = "list", length = 5)

# Start the loop 
for (i in 1:length(Different.Paths)) {
  
  # Select the path for which results should be plotted
  Path <- subset(combined.results, Pathway == Different.Paths[i])
  
  # Select the path for the control treatment separately (this will be our baseline reference) 
  Strip.Path <- subset(Paths.Strip, Pathway == Different.Paths[i])
  
  
  # Plot with ggplot
  All_Paths_Plotted[[i]] <- 
    ggplot() +
    # The value of the estimate and its 95% interval for each treatment (but not control)
    geom_point(data = Path, aes(x = Treatment, y = Estimate, colour = Treatment)) +
    geom_errorbar(data = Path, aes(x = Treatment,
                                   ymin = Estimate - 1.96*Std.Error, 
                                   ymax = Estimate + 1.96*Std.Error, 
                                   colour = Treatment), 
                  width=.2) +
    # The estimated value of the path for control plants, with 95% interval
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate)) + 
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate - 1.96 * Std.Error), linetype = 2) + 
    #geom_hline(data = Strip.Path, aes(yintercept = Estimate + 1.96 * Std.Error), linetype = 2) + 
    
    # Add some color and a nice layout of the figure
    labs(title = Different.Paths[i],x = "Cropping design", y = "Estimate") +
    scale_colour_manual(values = Droef.colors) +
    guides(colour = "none") +
    
    # This is a custom theme I specified. You can replace this with your own theme or 
    # "theme_bw()" or something similar.
    theme_bw()
  
}

# Define the layout of the plots 
Path_Plots_layout <- rbind(c(1:3),c(4:6)) 
Paths_Plotted <- marrangeGrob(All_Paths_Plotted, nrow = 2, ncol = 2,layout_matrix = Path_Plots_layout)

# Visualize the plots
Paths_Plotted

#subsection 6.3: Pathway comparison ----
All_Effects <- data.frame(matrix(nrow = 3, ncol = 0))

Treatment_Levels <- levels(combined.results$Treatment)

for (i in 1:length(Treatment_Levels)){
  
  # Select the treatment
  Path_Data <- subset(combined.results, Treatment == Treatment_Levels[i])
  
  # Effects of each variable on seed production
  # This is the same calculation you would do in Excel and requires you to 
  # write all of this stuff out for each SEM structure you want to use.
  
  # Proportion Marketable Weight
  #PMW_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Yieldloss"),]$Std.Estimate
  #PMW_Indirect <- 0
  #PMW_Total <- PMW_Direct + PMW_Indirect
  
  # Fresh weight wrapper leaves
  FWW_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.LOG_FWwrapper"),]$Std.Estimate
  FWW_Indirect <- 0
  FWW_Total <- FWW_Direct + FWW_Indirect
  
  # Leaves T2
  L2_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Leaves2"),]$Std.Estimate
  L2_Indirect <- 
    # Path over fresh weight wrapper leaves 
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Leaves2"),]$Std.Estimate * FWW_Total 
  L2_Total <- L2_Direct + L2_Indirect
  
  # Radius T2
  R2_Direct <- Path_Data[which(Path_Data$Pathway == "LOG_FWhead.Radius2"),]$Std.Estimate 
  R2_Indirect <- 
    # Path over fresh weight wrapper leaves
    Path_Data[which(Path_Data$Pathway == "LOG_FWwrapper.Radius2"),]$Std.Estimate * FWW_Total
  R2_Total <- R2_Direct + R2_Indirect
  
  # Store all the total effects in a dataframe
  Path_Effects <- as.data.frame(rbind(R2_Total,
                                      L2_Total,
                                      FWW_Total))
  
  # Annotate the dataframe with the treatment name
  colnames(Path_Effects) <- Treatment_Levels[i]
  
  # Store the result in a bigger dataframe that stores info for each iteration of the for loop
  All_Effects <- cbind(All_Effects,Path_Effects)
  
}

# Wrangle the resulting data frame into the right shape for a heatmap
Stacked_Effects <- data.frame("Treatment" = as.data.frame(stack(All_Effects))$ind,
                              "Path" = c("Early diameter",
                                         "Early number\nof leaves",
                                         "Fresh weight\nwrapper leaves"),
                              "TotalEffect" = as.data.frame(stack(All_Effects))$values)

# Plot a heatmap using ggplot
Stacked_Effects$Treatment2 <- factor(Stacked_Effects$Treatment, 
                                     levels = c("Monoculture", "Strip", "Strip_cultivar", "Strip_additive", "Strip_diversity"),
                                     labels = c("Monoculture", "Strip", "Strip\ncultivar", "Strip\nadditive", "Strip\ndiversity"))

png(filename = "Model 1 - Effect on FW head.png", width = 5400, height = 2720, res = 400)
ggplot(data = Stacked_Effects, aes(x = Treatment2, y = Path, fill = TotalEffect)) +
  geom_tile() +
  # Add the total effects (rounded to 2 numbers after the decimal point)
  geom_text(aes(label = sprintf("%.2f",TotalEffect)), size = 8) +
  scale_fill_gradient2(name = "Effect on\nfresh weight\nhead",
                       low = "#A51122",
                       mid = "#FFFFFF",
                       high = "#006228",
                       limits = c(-1, 1), 
                       breaks = seq(-1,1,by=0.5)) + 
  theme_bw() +
  theme(axis.title.x = element_blank(), axis.title.y = element_blank(),
        axis.text = element_text(size = 25),
        legend.title = element_text(size = 20), legend.text = element_text(size = 12)) +
  guides(size = "none")
dev.off()
